diff -ruN yapet-0.4.bak/csv2yapet/csvimport.cc yapet-0.4/csv2yapet/csvimport.cc
--- yapet-0.4.bak/csv2yapet/csvimport.cc	2009-07-08 18:47:47.000000000 +0200
+++ yapet-0.4/csv2yapet/csvimport.cc	2009-07-18 21:49:28.248643178 +0200
@@ -57,38 +57,27 @@
 #include <file.h>
 
 /**
- * Count the number of separators on the line.
+ * Removes the double quotes at the beginning and any escaped double quotes.
  *
- * @param s the line
+ * @param str the string to be cleaned up.
  *
- * @return the number of separators.
- */
-unsigned int
-CSVImport::countSeparator(const std::string& s) const {
-    unsigned int c = 0;
-    std::string::size_type pos = 0;
-    while ( (pos = s.find(separator, pos)) != std::string::npos ) {
-	c++;
-	pos++;
-    }
-    return c;
-}
-
-/**
- * Returns a vector holding the character positions of the separators.
- *
- * @param line the line
- *
- * @param posvec the vector filled with the positions
+ * @return the string \c str passed will be modified.
  */
 void
-CSVImport::getSeparatorPos(const std::string& line,
-			   std::vector<std::string::size_type>& posvec) const {
-    posvec.clear();
-    std::string::size_type pos = 0;
-    while ( (pos = line.find(separator, pos)) != std::string::npos ) {
-	posvec.push_back(pos);
-	pos++;
+CSVImport::cleanupValue(std::string& str) {
+    if (str.length() == 0) return;
+
+    if (str.at(0) == '"')
+	str = str.erase(0, 1);
+
+    if (str.at(str.length()-1) == '"')
+	str = str.erase(str.length()-1, 1);
+
+    std::string::size_type pos=0;
+    while ( ( pos = str.find("\"\"", pos)) != std::string::npos ) {
+	str.erase(pos,1);
+	if (pos + 1 < str.length() )
+	    pos++;
     }
 }
 
@@ -159,7 +148,7 @@
 	NUM_SEPARATORS;
 
     // used for logging purpose
-    unsigned int num_fields = NUM_SEPARATORS + 1;
+    const unsigned int num_fields = NUM_SEPARATORS + 1;
     char num_fields_str[5];
     snprintf(num_fields_str, 5, "%u", num_fields);
 
@@ -168,19 +157,67 @@
     std::list<YAPET::PartDec> list;
 
     char line[max_len];
-    std::vector<std::string::size_type> seppos;
+    // Holds the line number count
     unsigned long lineno = 0;
+    // Flag indicating whether we're in a quote or not
+    bool inquote = false;
+    // Array holding the field values of the csv file
+    std::string field_values[num_fields];
+    // Integer indicating which field has to be filled
+    int current_field = 0;
+    // Number of delimiters found per line
+    int num_sep_found = 0;
+    // The iterator for scanning the line character by character
+    std::string::size_type it=0;
+
     while (csvfile.getline(line, max_len) ) {
 	lineno++;
 	std::string l(line);
-	if (countSeparator(l) > NUM_SEPARATORS) {
-	    std::string tmp("Too many fields. Expected ");
-	    tmp += num_fields_str;
-	    tmp += " fields.";
-	    logError(lineno, tmp );
-	    continue;
+	// integer pointing to the last delimiter found
+	std::string::size_type last_sep = 0;
+
+	if (!inquote) {
+	    current_field = 0;
+	    num_sep_found = 0;
+	    for (unsigned int i = 0; i < num_fields; i++)
+		field_values[i].clear();
+	}
+
+	// Indicate scanning error
+	bool scan_error = false;
+	for (it=0; it < l.length(); it++) {
+	    // Flip the inquote flag when encountering a double quote
+	    if (l.at(it) == '"') {
+		inquote = !inquote;
+	    }
+
+	    if (!inquote && (l.at(it) == separator) ) {
+		num_sep_found++;
+		if (num_sep_found > NUM_SEPARATORS) {
+		    std::string tmp("Too many fields. Expected ");
+		    tmp += num_fields_str;
+		    tmp += " fields.";
+		    logError(lineno, tmp );
+		    scan_error = true;
+		    break;
+		}
+		field_values[current_field] = l.substr(last_sep, it - last_sep);
+		cleanupValue(field_values[current_field]);
+		last_sep = it + 1;
+		current_field++;
+	    }
 	}
-	if (countSeparator(l) < NUM_SEPARATORS) {
+
+	if (scan_error) continue;
+
+	// Make sure the last field will be extracted too, but check if the
+	// last separator has any value followed.
+	if (it > last_sep) {
+	    field_values[current_field] = l.substr(last_sep, it - last_sep);
+	    cleanupValue(field_values[current_field]);
+	}
+
+	if (!inquote && (num_sep_found < NUM_SEPARATORS) ) {
 	    std::string tmp("Too few fields. Expected ");
 	    tmp += num_fields_str;
 	    tmp += " fields.";
@@ -188,26 +225,17 @@
 	    continue;
 	}
 
-	getSeparatorPos(l, seppos);
-	if (seppos.size() == 0) {
-	    logError(lineno, "Unable to identify separators.");
-	    continue;
+	if (!inquote && (num_sep_found == NUM_SEPARATORS) ) {
+	    YAPET::Record<YAPET::PasswordRecord> record;
+	    YAPET::PasswordRecord *ptr_rec = record;
+	    strncpy((char*)ptr_rec->name, field_values[0].c_str(), YAPET::NAME_SIZE);
+	    strncpy((char*)ptr_rec->host, field_values[1].c_str(), YAPET::HOST_SIZE);
+	    strncpy((char*)ptr_rec->username, field_values[2].c_str(), YAPET::USERNAME_SIZE);
+	    strncpy((char*)ptr_rec->password, field_values[3].c_str(), YAPET::PASSWORD_SIZE);
+	    strncpy((char*)ptr_rec->comment, field_values[4].c_str(), YAPET::COMMENT_SIZE);
+	    list.push_back(YAPET::PartDec(record, key));
+	    if (verbose) std::cout << ".";
 	}
-
-	std::string name = l.substr(0, seppos[0]);
-	std::string host = l.substr(seppos[0]+1, seppos[1] - seppos[0] - 1);
-	std::string uname = l.substr(seppos[1]+1, seppos[2] - seppos[1] - 1);
-	std::string passwd = l.substr(seppos[2]+1, seppos[3] - seppos[2] - 1 );
-	std::string comment = l.substr(seppos[3]+1, l.length() - seppos[3]);
-	YAPET::Record<YAPET::PasswordRecord> record;
-	YAPET::PasswordRecord *ptr_rec = record;
-	strncpy((char*)ptr_rec->name, name.c_str(), YAPET::NAME_SIZE);
-	strncpy((char*)ptr_rec->host, host.c_str(), YAPET::HOST_SIZE);
-	strncpy((char*)ptr_rec->username, uname.c_str(), YAPET::USERNAME_SIZE);
-	strncpy((char*)ptr_rec->password, passwd.c_str(), YAPET::PASSWORD_SIZE);
-	strncpy((char*)ptr_rec->comment, comment.c_str(), YAPET::COMMENT_SIZE);
-	list.push_back(YAPET::PartDec(record, key));
-	if (verbose) std::cout << ".";
     }
     if (verbose) std::cout << std::endl;
     yapetfile.save(list);
diff -ruN yapet-0.4.bak/csv2yapet/csvimport.h yapet-0.4/csv2yapet/csvimport.h
--- yapet-0.4.bak/csv2yapet/csvimport.h	2009-07-10 20:36:44.000000000 +0200
+++ yapet-0.4/csv2yapet/csvimport.h	2009-07-18 21:02:10.224663449 +0200
@@ -36,32 +36,29 @@
 # include <stdexcept>
 #endif
 
-#ifdef HAVE_VECTOR
-# include <vector>
-#endif
-
 #ifdef HAVE_LIST
 # include <list>
 #endif
 
 /**
- * Log entry.
+ * The class taking care of converting a csv file.
  */
-struct LogEntry {
-	/**
-	 * The line number where the error occurred.
-	 */
-	unsigned int lineno;
+class CSVImport {
+    public:
 	/**
-	 * The error message.
+	 * Log entry.
 	 */
-	std::string message;
-};
+	struct LogEntry {
+		/**
+		 * The line number where the error occurred.
+		 */
+		unsigned int lineno;
+		/**
+		 * The error message.
+		 */
+		std::string message;
+	};
 
-/**
- * The class taking care of converting a csv file.
- */
-class CSVImport {
     private:
 	/**
 	 * Object assignment not allowed.
@@ -110,11 +107,8 @@
 	 */
 	std::list<LogEntry> logs;
 
-	//! Count the separators of the line provided.
-	unsigned int countSeparator(const std::string& s) const;
-	//! Returns the position of the separators in the line.
-	void getSeparatorPos(const std::string& line,
-			     std::vector<std::string::size_type>& posvec) const;
+	//! Cleanup the field values
+	void cleanupValue(std::string& str);
 	//! Log the given error
 	void logError(unsigned long lno, const std::string& errmsg);
 
diff -ruN yapet-0.4.bak/doc/csv2yapet.1 yapet-0.4/doc/csv2yapet.1
--- yapet-0.4.bak/doc/csv2yapet.1	2009-07-12 13:13:40.000000000 +0200
+++ yapet-0.4/doc/csv2yapet.1	2009-07-18 23:18:52.852663499 +0200
@@ -2,12 +2,12 @@
 .\"     Title: csv2yapet
 .\"    Author: [see the "AUTHOR" section]
 .\" Generator: DocBook XSL Stylesheets v1.74.3 <http://docbook.sf.net/>
-.\"      Date: 07/12/2009
+.\"      Date: 07/18/2009
 .\"    Manual: User Commands
 .\"    Source: csv2yapet 0.4
 .\"  Language: English
 .\"
-.TH "CSV2YAPET" "1" "07/12/2009" "csv2yapet 0\&.4" "User Commands"
+.TH "CSV2YAPET" "1" "07/18/2009" "csv2yapet 0\&.4" "User Commands"
 .\" -----------------------------------------------------------------
 .\" * set default formatting
 .\" -----------------------------------------------------------------
@@ -125,10 +125,12 @@
 option (refer to
 the section called \(lqOPTIONS\(rq)\&.
 .PP
-Fields containing the field separator character will lead to import errors (see also
-the section called \(lqBUGS\(rq)\&.
+Fields containing the field separator character have to be enclosed in double quotes (")\&.
 .PP
-The following table will describe the format of the source CSV file as expected by
+Double quote characters to be converted literally, has each to be preceded by another double quote character (see
+the section called \(lqEXAMPLES\(rq)\&.
+.PP
+The following table will describe the fields of the source CSV file as expected by
 \fBcsv2yapet\fR:
 .sp
 .it 1 an-trap
@@ -211,19 +213,8 @@
 An unexpected error occurred\&.
 .RE
 .SH "BUGS"
-.sp
-.RS 4
-.ie n \{\
-\h'-04'\(bu\h'+03'\c
-.\}
-.el \{\
-.sp -1
-.IP \(bu 2.3
-.\}
-If the field separating character is part of the field value, it is misinterpreted as field delimiter\&.
-.RE
 .PP
-Please report other bugs to the author (see
+Please report bugs to the author (see
 the section called \(lqAUTHOR\(rq)\&.
 .SH "EXAMPLES"
 .PP
@@ -231,6 +222,8 @@
 .PP
 The following example shows an excerpt of a CSV file as accepted for conversion by
 \fBcsv2yapet\fR\&.
+.PP
+As the second line shows, fields can be blank but the separator may not be omitted\&.
 .sp
 .if n \{\
 .RS 4
@@ -244,7 +237,26 @@
 .RE
 .\}
 .PP
-\fBExample\ \&2.\ \&Invoking csv2yapet.\fR
+\fBExample\ \&2.\ \&An example of a CSV file accepted by csv2yapet using double quotes.\fR
+.PP
+The following example shows an excerpt of a CSV file as accepted for conversion by
+\fBcsv2yapet\fR\&.
+.PP
+The first line demonstrates how to double quote fields containing the separator character\&. The second line shows how to literally convert double quote characters\&.
+.sp
+.if n \{\
+.RS 4
+.\}
+.nf
+"ssh, ftp, and http server",server\&.example\&.org,johndoe,secret,linux machine
+mail account,imap\&.email\&.org,john_doe,secret,"John ""the Unknown"" Doe"
+\&...
+.fi
+.if n \{\
+.RE
+.\}
+.PP
+\fBExample\ \&3.\ \&Invoking csv2yapet.\fR
 .PP
 The following example shows how to invoke
 \fBcsv2yapet\fR
diff -ruN yapet-0.4.bak/doc/csv2yapet.html yapet-0.4/doc/csv2yapet.html
--- yapet-0.4.bak/doc/csv2yapet.html	2009-07-12 13:13:55.000000000 +0200
+++ yapet-0.4/doc/csv2yapet.html	2009-07-18 23:19:05.848683847 +0200
@@ -30,9 +30,10 @@
 	  conversion and abort.</p></dd></dl></div></div><div class="refsect1" lang="en" xml:lang="en"><a id="sourcefileformat"></a><h2>SOURCE FILE FORMAT</h2><p>The source file <em class="replaceable"><code>src</code></em> to be converted has to
     be organized as CSV file. The default character for delimiting the fields
     is ',' (comma) unless specified differently on the command line providing
-    the <code class="option">-s</code> option (refer to <a class="xref" href="#options" title="OPTIONS">the section called “OPTIONS”</a>).</p><p>Fields containing the field separator character will lead to import
-    errors (see also <a class="xref" href="#bugs" title="BUGS">the section called “BUGS”</a>).</p><p>The following table will describe the format of the source CSV file
-    as expected by <span class="command"><strong>csv2yapet</strong></span>:</p><div class="table"><a id="id2509431"></a><p class="title"><b>Table 1. Source file format</b></p><div class="table-contents"><table summary="Source file format" width="100%" border="1"><colgroup><col align="center" /><col align="left" /></colgroup><thead><tr><th align="center">Column #</th><th align="left">YAPET record field</th></tr></thead><tbody><tr><td align="center">1</td><td align="left">Name</td></tr><tr><td align="center">2</td><td align="left">Host</td></tr><tr><td align="center">3</td><td align="left">Username</td></tr><tr><td align="center">4</td><td align="left">Password</td></tr><tr><td align="center">5</td><td align="left">Comment</td></tr></tbody></table></div></div><br class="table-break" /><p>See <a class="xref" href="#examples" title="EXAMPLES">the section called “EXAMPLES”</a> for an example CSV file.</p></div><div class="refsect1" lang="en" xml:lang="en"><a id="exitstatus"></a><h2>EXIST STATUS</h2><p>
+    the <code class="option">-s</code> option (refer to <a class="xref" href="#options" title="OPTIONS">the section called “OPTIONS”</a>).</p><p>Fields containing the field separator character have to be enclosed
+    in double quotes (").</p><p>Double quote characters to be converted literally, has each to be
+    preceded by another double quote character (see <a class="xref" href="#examples" title="EXAMPLES">the section called “EXAMPLES”</a>).</p><p>The following table will describe the fields of the source CSV file
+    as expected by <span class="command"><strong>csv2yapet</strong></span>:</p><div class="table"><a id="id2509505"></a><p class="title"><b>Table 1. Source file format</b></p><div class="table-contents"><table summary="Source file format" width="100%" border="1"><colgroup><col align="center" /><col align="left" /></colgroup><thead><tr><th align="center">Column #</th><th align="left">YAPET record field</th></tr></thead><tbody><tr><td align="center">1</td><td align="left">Name</td></tr><tr><td align="center">2</td><td align="left">Host</td></tr><tr><td align="center">3</td><td align="left">Username</td></tr><tr><td align="center">4</td><td align="left">Password</td></tr><tr><td align="center">5</td><td align="left">Comment</td></tr></tbody></table></div></div><br class="table-break" /><p>See <a class="xref" href="#examples" title="EXAMPLES">the section called “EXAMPLES”</a> for an example CSV file.</p></div><div class="refsect1" lang="en" xml:lang="en"><a id="exitstatus"></a><h2>EXIST STATUS</h2><p>
       </p><div class="variablelist"><dl><dt><span class="term"><span class="returnvalue">0</span></span></dt><dd><p>No error.
 	    </p></dd><dt><span class="term"><span class="returnvalue">1</span></span></dt><dd><p>Wrong command line arguments provided.
 	    </p></dd><dt><span class="term"><span class="returnvalue">2</span></span></dt><dd><p>The passwords provided on the standard input do not match.
@@ -40,13 +41,20 @@
 	    <code class="filename"><em class="replaceable"><code>dst</code></em></code> already exists.
 	    </p></dd><dt><span class="term"><span class="returnvalue">4</span></span></dt><dd><p>An unexpected error occurred.
 	    </p></dd></dl></div><p>
-    </p></div><div class="refsect1" lang="en" xml:lang="en"><a id="bugs"></a><h2>BUGS</h2><div class="itemizedlist"><ul type="disc"><li><p>If the field separating character is part of the field value,
-	  it is misinterpreted as field delimiter.</p></li></ul></div><p>Please report other bugs to the author (see <a class="xref" href="#author" title="AUTHOR">the section called “AUTHOR”</a>).</p></div><div class="refsect1" lang="en" xml:lang="en"><a id="examples"></a><h2>EXAMPLES</h2><div class="example"><a id="ex.csv"></a><p class="title"><b>Example 1. An example of a CSV file accepted by <span class="command">csv2yapet</span>.</b></p><div class="example-contents"><p>The following example shows an excerpt of a CSV file as accepted
-      for conversion by <span class="command"><strong>csv2yapet</strong></span>.</p><pre class="screen">
+    </p></div><div class="refsect1" lang="en" xml:lang="en"><a id="bugs"></a><h2>BUGS</h2><p>Please report bugs to the author (see <a class="xref" href="#author" title="AUTHOR">the section called “AUTHOR”</a>).</p></div><div class="refsect1" lang="en" xml:lang="en"><a id="examples"></a><h2>EXAMPLES</h2><div class="example"><a id="ex.csv1"></a><p class="title"><b>Example 1. An example of a CSV file accepted by <span class="command">csv2yapet</span>.</b></p><div class="example-contents"><p>The following example shows an excerpt of a CSV file as accepted
+      for conversion by <span class="command"><strong>csv2yapet</strong></span>.</p><p>As the second line shows, fields can be blank but the separator may
+      not be omitted.</p><pre class="screen">
 ssh host,host.example.org,johndoe,secret,linux machine
 mail account,imap.email.org,john_doe,secret,
 …
-</pre></div></div><br class="example-break" /><div class="example"><a id="ex.invoc1"></a><p class="title"><b>Example 2. Invoking <span class="command">csv2yapet</span>.</b></p><div class="example-contents"><p>The following example shows how to invoke <span class="command"><strong>csv2yapet</strong></span> in order to
+</pre></div></div><br class="example-break" /><div class="example"><a id="ex.csv2"></a><p class="title"><b>Example 2. An example of a CSV file accepted by <span class="command">csv2yapet</span> using double quotes.</b></p><div class="example-contents"><p>The following example shows an excerpt of a CSV file as accepted
+      for conversion by <span class="command"><strong>csv2yapet</strong></span>.</p><p>The first line demonstrates how to double quote fields containing
+      the separator character. The second line shows how to literally convert
+      double quote characters.</p><pre class="screen">
+"ssh, ftp, and http server",server.example.org,johndoe,secret,linux machine
+mail account,imap.email.org,john_doe,secret,"John ""the Unknown"" Doe"
+…
+</pre></div></div><br class="example-break" /><div class="example"><a id="ex.invoc1"></a><p class="title"><b>Example 3. Invoking <span class="command">csv2yapet</span>.</b></p><div class="example-contents"><p>The following example shows how to invoke <span class="command"><strong>csv2yapet</strong></span> in order to
       convert a CSV file to an YAPET file. If the <code class="option">-s</code> option is
       not given, <span class="command"><strong>csv2yapet</strong></span> will ask for a password as shown:</p><pre class="screen">
 <code class="prompt">$</code> <span class="command"><strong>csv2yapet</strong></span> <code class="filename">passwords.csv</code> <code class="filename">passwords.pet</code>
diff -ruN yapet-0.4.bak/doc/csv2yapet.sgml yapet-0.4/doc/csv2yapet.sgml
--- yapet-0.4.bak/doc/csv2yapet.sgml	2009-07-12 13:13:31.000000000 +0200
+++ yapet-0.4/doc/csv2yapet.sgml	2009-07-18 23:18:45.424684272 +0200
@@ -2,11 +2,11 @@
 <!DOCTYPE refentry PUBLIC "-//OASIS//DTD DocBook XML V4.5//EN"
 	  "http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"
 [
-<!ENTITY cpr SYSTEM "/home/java/yapet/doc/copyright.sgml">
-<!ENTITY supplatforms SYSTEM "/home/java/yapet/doc/supportedplatforms.sgml">
-<!ENTITY pwrecord SYSTEM "/home/java/yapet/doc/pwrecord.sgml">
-<!ENTITY caution SYSTEM "/home/java/yapet/doc/caution.sgml">
-<!ENTITY license SYSTEM "/home/java/yapet/doc/license.sgml">
+<!ENTITY cpr SYSTEM "./copyright.sgml">
+<!ENTITY supplatforms SYSTEM "./supportedplatforms.sgml">
+<!ENTITY pwrecord SYSTEM "./pwrecord.sgml">
+<!ENTITY caution SYSTEM "./caution.sgml">
+<!ENTITY license SYSTEM "./license.sgml">
 <!ENTITY OPENSSL "<citerefentry><refentrytitle>ssl</refentrytitle>
 <manvolnum>3</manvolnum></citerefentry>">
 <!ENTITY CRYPTO "<citerefentry><refentrytitle>crypto</refentrytitle>
@@ -224,10 +224,14 @@
     the <option>-s</option> option (refer to <xref linkend="options"
     />).</para>
 
-    <para>Fields containing the field separator character will lead to import
-    errors (see also <xref linkend="bugs" />).</para>
+    <para>Fields containing the field separator character have to be enclosed
+    in double quotes (").</para>
 
-    <para>The following table will describe the format of the source CSV file
+    <para>Double quote characters to be converted literally, has each to be
+    preceded by another double quote character (see <xref linkend="examples"
+    />).</para>
+
+    <para>The following table will describe the fields of the source CSV file
     as expected by &csv2yapet;:</para>
 
     <table pgwide="1">
@@ -346,15 +350,7 @@
   <refsect1 id="bugs">
     <title>BUGS</title>
 
-    <itemizedlist>
-      <listitem>
-	  <para>If the field separating character is part of the field value,
-	  it is misinterpreted as field delimiter.</para>
-      </listitem>
-    </itemizedlist>
-
-
-    <para>Please report other bugs to the author (see <xref linkend="author"
+    <para>Please report bugs to the author (see <xref linkend="author"
     />).</para>
 
   </refsect1>
@@ -368,11 +364,14 @@
   <refsect1 id="examples">
     <title>EXAMPLES</title>
 
-    <example id="ex.csv">
+    <example id="ex.csv1">
       <title>An example of a CSV file accepted by &csv2yapet;.</title>
 
       <para>The following example shows an excerpt of a CSV file as accepted
       for conversion by &csv2yapet;.</para>
+
+      <para>As the second line shows, fields can be blank but the separator may
+      not be omitted.</para>
 <screen>
 ssh host,host.example.org,johndoe,secret,linux machine
 mail account,imap.email.org,john_doe,secret,
@@ -380,6 +379,23 @@
 </screen>
     </example>
 
+    <example id="ex.csv2">
+      <title>An example of a CSV file accepted by &csv2yapet; using double quotes.</title>
+
+      <para>The following example shows an excerpt of a CSV file as accepted
+      for conversion by &csv2yapet;.</para>
+
+      <para>The first line demonstrates how to double quote fields containing
+      the separator character. The second line shows how to literally convert
+      double quote characters.</para>
+
+<screen>
+"ssh, ftp, and http server",server.example.org,johndoe,secret,linux machine
+mail account,imap.email.org,john_doe,secret,"John ""the Unknown"" Doe"
+&hellip;
+</screen>
+    </example>
+
     <example id="ex.invoc1">
       <title>Invoking &csv2yapet;.</title>
 
diff -ruN yapet-0.4.bak/doc/csv2yapet.sgml.in yapet-0.4/doc/csv2yapet.sgml.in
--- yapet-0.4.bak/doc/csv2yapet.sgml.in	2009-07-12 12:55:27.000000000 +0200
+++ yapet-0.4/doc/csv2yapet.sgml.in	2009-07-18 23:07:29.888683758 +0200
@@ -224,10 +224,14 @@
     the <option>-s</option> option (refer to <xref linkend="options"
     />).</para>
 
-    <para>Fields containing the field separator character will lead to import
-    errors (see also <xref linkend="bugs" />).</para>
+    <para>Fields containing the field separator character have to be enclosed
+    in double quotes (").</para>
 
-    <para>The following table will describe the format of the source CSV file
+    <para>Double quote characters to be converted literally, has each to be
+    preceded by another double quote character (see <xref linkend="examples"
+    />).</para>
+
+    <para>The following table will describe the fields of the source CSV file
     as expected by &csv2yapet;:</para>
 
     <table pgwide="1">
@@ -346,15 +350,7 @@
   <refsect1 id="bugs">
     <title>BUGS</title>
 
-    <itemizedlist>
-      <listitem>
-	  <para>If the field separating character is part of the field value,
-	  it is misinterpreted as field delimiter.</para>
-      </listitem>
-    </itemizedlist>
-
-
-    <para>Please report other bugs to the author (see <xref linkend="author"
+    <para>Please report bugs to the author (see <xref linkend="author"
     />).</para>
 
   </refsect1>
@@ -368,11 +364,14 @@
   <refsect1 id="examples">
     <title>EXAMPLES</title>
 
-    <example id="ex.csv">
+    <example id="ex.csv1">
       <title>An example of a CSV file accepted by &csv2yapet;.</title>
 
       <para>The following example shows an excerpt of a CSV file as accepted
       for conversion by &csv2yapet;.</para>
+
+      <para>As the second line shows, fields can be blank but the separator may
+      not be omitted.</para>
 <screen>
 ssh host,host.example.org,johndoe,secret,linux machine
 mail account,imap.email.org,john_doe,secret,
@@ -380,6 +379,23 @@
 </screen>
     </example>
 
+    <example id="ex.csv2">
+      <title>An example of a CSV file accepted by &csv2yapet; using double quotes.</title>
+
+      <para>The following example shows an excerpt of a CSV file as accepted
+      for conversion by &csv2yapet;.</para>
+
+      <para>The first line demonstrates how to double quote fields containing
+      the separator character. The second line shows how to literally convert
+      double quote characters.</para>
+
+<screen>
+"ssh, ftp, and http server",server.example.org,johndoe,secret,linux machine
+mail account,imap.email.org,john_doe,secret,"John ""the Unknown"" Doe"
+&hellip;
+</screen>
+    </example>
+
     <example id="ex.invoc1">
       <title>Invoking &csv2yapet;.</title>
 
diff -ruN yapet-0.4.bak/doc/DESIGN.html yapet-0.4/doc/DESIGN.html
--- yapet-0.4.bak/doc/DESIGN.html	2009-07-12 13:13:47.000000000 +0200
+++ yapet-0.4/doc/DESIGN.html	2009-07-18 23:18:58.964653190 +0200
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>YAPET - Yet Another Password Encryption Tool 0.4</title><meta name="generator" content="DocBook XSL Stylesheets V1.74.3" /></head><body><div class="article" lang="en" xml:lang="en"><div class="titlepage"><div><div><h2 class="title"><a id="id2510958"></a>YAPET - Yet Another Password Encryption Tool 0.4</h2></div><div><h3 class="subtitle"><i>YAPET - Design</i></h3></div><div><div class="author"><h3 class="author"><span class="firstname">Rafael</span> <span class="surname">Ostertag</span></h3></div></div><div><p class="releaseinfo">
+<html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>YAPET - Yet Another Password Encryption Tool 0.4</title><meta name="generator" content="DocBook XSL Stylesheets V1.74.3" /></head><body><div class="article" lang="en" xml:lang="en"><div class="titlepage"><div><div><h2 class="title"><a id="id2511018"></a>YAPET - Yet Another Password Encryption Tool 0.4</h2></div><div><h3 class="subtitle"><i>YAPET - Design</i></h3></div><div><div class="author"><h3 class="author"><span class="firstname">Rafael</span> <span class="surname">Ostertag</span></h3></div></div><div><p class="releaseinfo">
       $Id: DESIGN.sgml.in 2305 2009-04-13 11:27:46Z rafi $
     </p></div><div><p class="copyright">Copyright © 2008, 2009 Rafael Ostertag &lt;rafi@guengel.ch&gt;</p></div></div><hr /></div><div class="toc"><p><b>Table of Contents</b></p><dl><dt><span class="sect1"><a href="#general">General</a></span></dt><dt><span class="sect1"><a href="#masterpassword">Master Password</a></span></dt><dt><span class="sect1"><a href="#encryptionkey">Encryption Key</a></span></dt><dt><span class="sect1"><a href="#filestructure">File Structure</a></span></dt><dd><dl><dt><span class="sect2"><a href="#recogstring">Recognition String</a></span></dt><dt><span class="sect2"><a href="#fileheader">Header</a></span></dt><dt><span class="sect2"><a href="#passwordrecord">Password Records</a></span></dt><dt><span class="sect2"><a href="#example">Example</a></span></dt></dl></dd><dt><span class="sect1"><a href="#security">Security</a></span></dt><dt><span class="sect1"><a href="#references">References</a></span></dt></dl></div><div class="sect1" lang="en" xml:lang="en"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="general"></a>General</h2></div></div></div><p>YAPET stores passwords encrypted on disk. Passwords are kept in
     records with additional information. A record is comprised by the following
diff -ruN yapet-0.4.bak/doc/DESIGN.sgml yapet-0.4/doc/DESIGN.sgml
--- yapet-0.4.bak/doc/DESIGN.sgml	2009-07-12 13:13:31.000000000 +0200
+++ yapet-0.4/doc/DESIGN.sgml	2009-07-18 23:18:45.372663454 +0200
@@ -2,9 +2,9 @@
 <!DOCTYPE article PUBLIC "-//OASIS//DTD DocBook XML V4.5//EN"
 "http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"
 [
-<!ENTITY cpr SYSTEM "/home/java/yapet/doc/copyright.sgml">
-<!ENTITY supplatforms SYSTEM "/home/java/yapet/doc/supportedplatforms.sgml">
-<!ENTITY pwrecord SYSTEM "/home/java/yapet/doc/pwrecord.sgml">
+<!ENTITY cpr SYSTEM "./copyright.sgml">
+<!ENTITY supplatforms SYSTEM "./supportedplatforms.sgml">
+<!ENTITY pwrecord SYSTEM "./pwrecord.sgml">
 <!ENTITY OPENSSL "<citerefentry><refentrytitle>ssl</refentrytitle>
 <manvolnum>3</manvolnum></citerefentry>">
 <!ENTITY CRYPTO "<citerefentry><refentrytitle>crypto</refentrytitle>
diff -ruN yapet-0.4.bak/doc/INSTALL.sgml yapet-0.4/doc/INSTALL.sgml
--- yapet-0.4.bak/doc/INSTALL.sgml	2009-07-12 13:13:31.000000000 +0200
+++ yapet-0.4/doc/INSTALL.sgml	2009-07-18 23:18:45.272622909 +0200
@@ -2,9 +2,9 @@
 <!DOCTYPE article PUBLIC "-//OASIS//DTD DocBook XML V4.5//EN"
 	  "http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"
 [
-<!ENTITY cpr SYSTEM "/home/java/yapet/doc/copyright.sgml">
-<!ENTITY preamble SYSTEM "/home/java/yapet/doc/preamble.sgml">
-<!ENTITY supplatforms SYSTEM "/home/java/yapet/doc/supportedplatforms.sgml">
+<!ENTITY cpr SYSTEM "./copyright.sgml">
+<!ENTITY preamble SYSTEM "./preamble.sgml">
+<!ENTITY supplatforms SYSTEM "./supportedplatforms.sgml">
 <!ENTITY OPENSSL "<citerefentry><refentrytitle>ssl</refentrytitle>
 <manvolnum>3</manvolnum></citerefentry>">
 <!ENTITY CURSES "<citerefentry><refentrytitle>curses</refentrytitle>
diff -ruN yapet-0.4.bak/doc/README.Cygwin.sgml yapet-0.4/doc/README.Cygwin.sgml
--- yapet-0.4.bak/doc/README.Cygwin.sgml	2009-07-12 13:13:31.000000000 +0200
+++ yapet-0.4/doc/README.Cygwin.sgml	2009-07-18 23:18:45.196663493 +0200
@@ -2,9 +2,9 @@
 <!DOCTYPE article PUBLIC "-//OASIS//DTD DocBook XML V4.5//EN"
 	  "http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"
 [
-<!ENTITY cpr SYSTEM "/home/java/yapet/doc/copyright.sgml">
-<!ENTITY supplatforms SYSTEM "/home/java/yapet/doc/supportedplatforms.sgml">
-<!ENTITY caution SYSTEM "/home/java/yapet/doc/caution.sgml">
+<!ENTITY cpr SYSTEM "./copyright.sgml">
+<!ENTITY supplatforms SYSTEM "./supportedplatforms.sgml">
+<!ENTITY caution SYSTEM "./caution.sgml">
 <!ENTITY OPENSSL "<citerefentry><refentrytitle>ssl</refentrytitle>
 <manvolnum>3</manvolnum></citerefentry>">
 <!ENTITY CURSES "<citerefentry><refentrytitle>curses</refentrytitle>
diff -ruN yapet-0.4.bak/doc/README.html yapet-0.4/doc/README.html
--- yapet-0.4.bak/doc/README.html	2009-07-12 13:13:43.000000000 +0200
+++ yapet-0.4/doc/README.html	2009-07-18 23:18:55.872704020 +0200
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>YAPET - Yet Another Password Encryption Tool 0.4</title><meta name="generator" content="DocBook XSL Stylesheets V1.74.3" /></head><body><div class="article" lang="en" xml:lang="en"><div class="titlepage"><div><div><h2 class="title"><a id="id2510950"></a>YAPET - Yet Another Password Encryption Tool 0.4</h2></div><div><div class="author"><h3 class="author"><span class="firstname">Rafael</span> <span class="surname">Ostertag</span></h3></div></div><div><p class="releaseinfo">
+<html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>YAPET - Yet Another Password Encryption Tool 0.4</title><meta name="generator" content="DocBook XSL Stylesheets V1.74.3" /></head><body><div class="article" lang="en" xml:lang="en"><div class="titlepage"><div><div><h2 class="title"><a id="id2510735"></a>YAPET - Yet Another Password Encryption Tool 0.4</h2></div><div><div class="author"><h3 class="author"><span class="firstname">Rafael</span> <span class="surname">Ostertag</span></h3></div></div><div><p class="releaseinfo">
       $Id: README.sgml.in 2465 2009-07-12 10:55:25Z rafi $
     </p></div><div><p class="copyright">Copyright © 2008, 2009 Rafael Ostertag &lt;rafi@guengel.ch&gt;</p></div></div><hr /></div><div class="toc"><p><b>Table of Contents</b></p><dl><dt><span class="sect1"><a href="#intro">Introduction</a></span></dt><dt><span class="sect1"><a href="#motivation">Motivation</a></span></dt><dt><span class="sect1"><a href="#platforms">Supported Platforms</a></span></dt><dt><span class="sect1"><a href="#features">Features</a></span></dt><dt><span class="sect1"><a href="#installation">Installation</a></span></dt><dt><span class="sect1"><a href="#usage">Usage</a></span></dt><dt><span class="sect1"><a href="#design">Design</a></span></dt><dt><span class="sect1"><a href="#caution">A Word of Caution</a></span></dt><dt><span class="sect1"><a href="#license">License</a></span></dt></dl></div><div class="sect1" lang="en" xml:lang="en"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="intro"></a>Introduction</h2></div></div></div><p>YAPET is a curses based password encryption tool using the Blowfish
     encryption algorithm to store password records encrypted on disk. Its
diff -ruN yapet-0.4.bak/doc/README.sgml yapet-0.4/doc/README.sgml
--- yapet-0.4.bak/doc/README.sgml	2009-07-12 13:13:31.000000000 +0200
+++ yapet-0.4/doc/README.sgml	2009-07-18 23:18:45.108663552 +0200
@@ -2,10 +2,10 @@
 <!DOCTYPE article PUBLIC "-//OASIS//DTD DocBook XML V4.5//EN"
 	  "http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"
 [
-<!ENTITY cpr SYSTEM "/home/java/yapet/doc/copyright.sgml">
-<!ENTITY supplatforms SYSTEM "/home/java/yapet/doc/supportedplatforms.sgml">
-<!ENTITY caution SYSTEM "/home/java/yapet/doc/caution.sgml">
-<!ENTITY license SYSTEM "/home/java/yapet/doc/license.sgml">
+<!ENTITY cpr SYSTEM "./copyright.sgml">
+<!ENTITY supplatforms SYSTEM "./supportedplatforms.sgml">
+<!ENTITY caution SYSTEM "./caution.sgml">
+<!ENTITY license SYSTEM "./license.sgml">
 <!ENTITY OPENSSL "<citerefentry><refentrytitle>ssl</refentrytitle>
 <manvolnum>3</manvolnum></citerefentry>">
 <!ENTITY CURSES "<citerefentry><refentrytitle>curses</refentrytitle>
diff -ruN yapet-0.4.bak/doc/yapet.1 yapet-0.4/doc/yapet.1
--- yapet-0.4.bak/doc/yapet.1	2009-07-12 13:13:35.000000000 +0200
+++ yapet-0.4/doc/yapet.1	2009-07-18 23:18:49.072643190 +0200
@@ -2,12 +2,12 @@
 .\"     Title: yapet
 .\"    Author: [see the "AUTHOR" section]
 .\" Generator: DocBook XSL Stylesheets v1.74.3 <http://docbook.sf.net/>
-.\"      Date: 07/12/2009
+.\"      Date: 07/18/2009
 .\"    Manual: User Commands
 .\"    Source: yapet 0.4
 .\"  Language: English
 .\"
-.TH "YAPET" "1" "07/12/2009" "yapet 0\&.4" "User Commands"
+.TH "YAPET" "1" "07/18/2009" "yapet 0\&.4" "User Commands"
 .\" -----------------------------------------------------------------
 .\" * set default formatting
 .\" -----------------------------------------------------------------
diff -ruN yapet-0.4.bak/doc/yapet.sgml yapet-0.4/doc/yapet.sgml
--- yapet-0.4.bak/doc/yapet.sgml	2009-07-12 13:13:31.000000000 +0200
+++ yapet-0.4/doc/yapet.sgml	2009-07-18 23:18:45.044654275 +0200
@@ -2,11 +2,11 @@
 <!DOCTYPE refentry PUBLIC "-//OASIS//DTD DocBook XML V4.5//EN"
 	  "http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"
 [
-<!ENTITY cpr SYSTEM "/home/java/yapet/doc/copyright.sgml">
-<!ENTITY supplatforms SYSTEM "/home/java/yapet/doc/supportedplatforms.sgml">
-<!ENTITY pwrecord SYSTEM "/home/java/yapet/doc/pwrecord.sgml">
-<!ENTITY caution SYSTEM "/home/java/yapet/doc/caution.sgml">
-<!ENTITY license SYSTEM "/home/java/yapet/doc/license.sgml">
+<!ENTITY cpr SYSTEM "./copyright.sgml">
+<!ENTITY supplatforms SYSTEM "./supportedplatforms.sgml">
+<!ENTITY pwrecord SYSTEM "./pwrecord.sgml">
+<!ENTITY caution SYSTEM "./caution.sgml">
+<!ENTITY license SYSTEM "./license.sgml">
 <!ENTITY OPENSSL "<citerefentry><refentrytitle>ssl</refentrytitle>
 <manvolnum>3</manvolnum></citerefentry>">
 <!ENTITY CRYPTO "<citerefentry><refentrytitle>crypto</refentrytitle>
diff -ruN yapet-0.4.bak/tests/import10.cc yapet-0.4/tests/import10.cc
--- yapet-0.4.bak/tests/import10.cc	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/import10.cc	2009-07-18 22:10:17.144663477 +0200
@@ -0,0 +1,53 @@
+// $Id$
+// Checks whether or not the import of import9 worked.
+// Relies on test6.csv
+
+#include <string.h>
+
+#include <iostream>
+
+#include <key.h>
+#include <crypt.h>
+#include <structs.h>
+#include <record.h>
+#include <partdec.h>
+#include <file.h>
+
+// Keep them define's here, since tests.h only defines the default if they are
+// not predefined
+#define ROUNDS 200
+#define NAME "\"Test name %d"
+#define HOST "Test host %d\""
+#define UNAME "Test \"username %d"
+#define PW "Test \"password\" %d"
+#define COMMENT "Test \"\"comment %d\"\""
+
+#include "tests.h"
+#include "testpaths.h"
+
+int main(int, char**) {
+    std::cout << "Check if import9 worked... " << std::endl;
+    try {
+	YAPET::Key key("test6");
+	YAPET::File file("test6.pet", key, false);
+	std::list<YAPET::PartDec> list = file.read(key);
+	if (list.size() != ROUNDS) {
+	    std::cout << "no" << std::endl;
+	    return 1;
+	}
+
+	std::list<YAPET::PartDec>::iterator it = list.begin();
+
+	for(int i=0; it != list.end(); i++) {
+	    check_record(*it, key, i);
+	    it++;
+	}
+
+    } catch (std::exception& ex) {
+	std::cout << "no" << std::endl;
+	std::cout << ex.what() << std::endl;
+	return 1;
+    }
+    std::cout << "yes" << std::endl;
+    return 0;
+}
diff -ruN yapet-0.4.bak/tests/import11.cc yapet-0.4/tests/import11.cc
--- yapet-0.4.bak/tests/import11.cc	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/import11.cc	2009-07-18 22:31:05.892663481 +0200
@@ -0,0 +1,35 @@
+// $Id$
+//
+// Tests whether or not import works with double quoted values and embedded
+// delimiters
+//
+// Relies on test7.csv
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#ifdef HAVE_IOSTREAM
+# include <iostream>
+#endif
+
+#include <csvimport.h>
+
+#include "testpaths.h"
+
+int main (int, char**) {
+    try {
+	std::cout << "Importing from test7.csv" << std::endl;;
+	CSVImport imp(SRCDIR "/test7.csv", "test7.pet", ',');
+	imp.import("test7");
+	if (imp.hadErrors())
+	    return 1;
+	if (imp.numErrors() != 0)
+	    return 1;
+    } catch(std::exception& ex) {
+	std::cout << ex.what() << std::endl;
+	return 1;
+    }
+
+    return 0;
+}
diff -ruN yapet-0.4.bak/tests/import12.cc yapet-0.4/tests/import12.cc
--- yapet-0.4.bak/tests/import12.cc	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/import12.cc	2009-07-18 22:32:22.484663466 +0200
@@ -0,0 +1,53 @@
+// $Id$
+// Checks whether or not the import of import10 worked.
+// Relies on test7.csv
+
+#include <string.h>
+
+#include <iostream>
+
+#include <key.h>
+#include <crypt.h>
+#include <structs.h>
+#include <record.h>
+#include <partdec.h>
+#include <file.h>
+
+// Keep them define's here, since tests.h only defines the default if they are
+// not predefined
+#define ROUNDS 200
+#define NAME ",Test name %d"
+#define HOST "Test, host %d"
+#define UNAME "Test username, %d"
+#define PW "Test password %d"
+#define COMMENT "Test comment %d,"
+
+#include "tests.h"
+#include "testpaths.h"
+
+int main(int, char**) {
+    std::cout << "Check if import11 worked... " << std::endl;
+    try {
+	YAPET::Key key("test7");
+	YAPET::File file("test7.pet", key, false);
+	std::list<YAPET::PartDec> list = file.read(key);
+	if (list.size() != ROUNDS) {
+	    std::cout << "no" << std::endl;
+	    return 1;
+	}
+
+	std::list<YAPET::PartDec>::iterator it = list.begin();
+
+	for(int i=0; it != list.end(); i++) {
+	    check_record(*it, key, i);
+	    it++;
+	}
+
+    } catch (std::exception& ex) {
+	std::cout << "no" << std::endl;
+	std::cout << ex.what() << std::endl;
+	return 1;
+    }
+    std::cout << "yes" << std::endl;
+    return 0;
+}
diff -ruN yapet-0.4.bak/tests/import13.cc yapet-0.4/tests/import13.cc
--- yapet-0.4.bak/tests/import13.cc	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/import13.cc	2009-07-18 22:41:40.572663472 +0200
@@ -0,0 +1,40 @@
+// $Id$
+//
+// Tests the error detection when double quoting is wrong.
+//
+// Relies on test8.csv
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#ifdef HAVE_IOSTREAM
+# include <iostream>
+#endif
+
+
+#include <csvimport.h>
+#include "testpaths.h"
+
+int main (int, char**) {
+    try {
+	std::cout << "Importing from test8.csv" << std::endl;
+	std::cout << "Testing for error recognition" << std::endl;
+	CSVImport imp(SRCDIR "/test8.csv", "test8.pet", ',');
+	imp.import("test8");
+	imp.printLog();
+	if (imp.numErrors() != 1)
+	    return 1;
+	std::list<CSVImport::LogEntry> logs(imp.getLog());
+	if (logs.size() != 1)
+	    return 1;
+	std::list<CSVImport::LogEntry>::const_iterator it = logs.begin();
+	if ((*it).lineno != 3)
+	    return 1;
+    } catch(std::exception& ex) {
+	std::cout << ex.what() << std::endl;
+	return 1;
+    }
+
+    return 0;
+}
diff -ruN yapet-0.4.bak/tests/import14.cc yapet-0.4/tests/import14.cc
--- yapet-0.4.bak/tests/import14.cc	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/import14.cc	2009-07-18 22:48:32.520663478 +0200
@@ -0,0 +1,38 @@
+// $Id$
+//
+// Tests whether or not strange input make the import choke (using double
+// quotes)
+//
+// Relies on test9.csv
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#ifdef HAVE_IOSTREAM
+# include <iostream>
+#endif
+
+
+#include <csvimport.h>
+#include "testpaths.h"
+
+int main (int, char**) {
+    try {
+	std::cout << "Importing from test9.csv" << std::endl;
+	std::cout << "Testing import of strange things" << std::endl;
+	CSVImport imp( SRCDIR "/test9.csv", "test9.pet", ',');
+	imp.import("test9");
+	if (imp.hadErrors()) {
+	    imp.printLog();
+	    return 1;
+	}
+	if (imp.numErrors() != 0)
+	    return 1;
+    } catch(std::exception& ex) {
+	std::cout << ex.what() << std::endl;
+	return 1;
+    }
+
+    return 0;
+}
diff -ruN yapet-0.4.bak/tests/import2.cc yapet-0.4/tests/import2.cc
--- yapet-0.4.bak/tests/import2.cc	2009-07-07 21:05:34.000000000 +0200
+++ yapet-0.4/tests/import2.cc	2009-07-18 20:16:46.180643271 +0200
@@ -22,13 +22,15 @@
 #define ROUNDS 200
 
 int main(int, char**) {
-    std::cout << "Check if import1 worked" << std::endl;
+    std::cout << "Check if import1 worked... " << std::endl;
     try {
 	YAPET::Key key("test1");
 	YAPET::File file("test1.pet", key, false);
 	std::list<YAPET::PartDec> list = file.read(key);
-	if (list.size() != ROUNDS)
+	if (list.size() != ROUNDS) {
+	    std::cout << "no" << std::endl;
 	    return 1;
+	}
 
 	std::list<YAPET::PartDec>::iterator it = list.begin();
 
@@ -38,8 +40,10 @@
 	}
 
     } catch (std::exception& ex) {
+	std::cout << "no" << std::endl;
 	std::cout << ex.what() << std::endl;
 	return 1;
     }
+    std::cout << "yes" << std::endl;
     return 0;
 }
diff -ruN yapet-0.4.bak/tests/import3.cc yapet-0.4/tests/import3.cc
--- yapet-0.4.bak/tests/import3.cc	2009-07-08 00:20:11.000000000 +0200
+++ yapet-0.4/tests/import3.cc	2009-07-17 19:39:49.840704022 +0200
@@ -23,10 +23,10 @@
 	imp.printLog();
 	if (imp.numErrors() != 2)
 	    return 1;
-	std::list<LogEntry> logs(imp.getLog());
+	std::list<CSVImport::LogEntry> logs(imp.getLog());
 	if (logs.size() != 2)
 	    return 1;
-	std::list<LogEntry>::const_iterator it = logs.begin();
+	std::list<CSVImport::LogEntry>::const_iterator it = logs.begin();
 	if ((*it).lineno != 2)
 	    return 1;
 	it++;
diff -ruN yapet-0.4.bak/tests/import7.cc yapet-0.4/tests/import7.cc
--- yapet-0.4.bak/tests/import7.cc	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/import7.cc	2009-07-18 20:35:24.344663767 +0200
@@ -0,0 +1,32 @@
+// $Id$
+// Tests whether or not import works with double quoted values
+// Relies on test5.csv
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#ifdef HAVE_IOSTREAM
+# include <iostream>
+#endif
+
+#include <csvimport.h>
+
+#include "testpaths.h"
+
+int main (int, char**) {
+    try {
+	std::cout << "Importing from test5.csv" << std::endl;;
+	CSVImport imp(SRCDIR "/test5.csv", "test5.pet", ',');
+	imp.import("test5");
+	if (imp.hadErrors())
+	    return 1;
+	if (imp.numErrors() != 0)
+	    return 1;
+    } catch(std::exception& ex) {
+	std::cout << ex.what() << std::endl;
+	return 1;
+    }
+
+    return 0;
+}
diff -ruN yapet-0.4.bak/tests/import8.cc yapet-0.4/tests/import8.cc
--- yapet-0.4.bak/tests/import8.cc	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/import8.cc	2009-07-18 21:18:24.164623033 +0200
@@ -0,0 +1,49 @@
+// $Id$
+// Checks whether or not the import of import7 worked.
+// Relies on test5.csv
+
+#include <string.h>
+
+#include <iostream>
+
+#include <key.h>
+#include <crypt.h>
+#include <structs.h>
+#include <record.h>
+#include <partdec.h>
+#include <file.h>
+
+#include "tests.h"
+#include "testpaths.h"
+
+#ifdef ROUNDS
+#undef ROUNDS
+#endif
+#define ROUNDS 200
+
+int main(int, char**) {
+    std::cout << "Check if import7 worked... " << std::endl;
+    try {
+	YAPET::Key key("test5");
+	YAPET::File file("test5.pet", key, false);
+	std::list<YAPET::PartDec> list = file.read(key);
+	if (list.size() != ROUNDS) {
+	    std::cout << "no" << std::endl;
+	    return 1;
+	}
+
+	std::list<YAPET::PartDec>::iterator it = list.begin();
+
+	for(int i=0; it != list.end(); i++) {
+	    check_record(*it, key, i);
+	    it++;
+	}
+
+    } catch (std::exception& ex) {
+	std::cout << "no" << std::endl;
+	std::cout << ex.what() << std::endl;
+	return 1;
+    }
+    std::cout << "yes" << std::endl;
+    return 0;
+}
diff -ruN yapet-0.4.bak/tests/import9.cc yapet-0.4/tests/import9.cc
--- yapet-0.4.bak/tests/import9.cc	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/import9.cc	2009-07-18 21:17:29.196663498 +0200
@@ -0,0 +1,35 @@
+// $Id$
+//
+// Tests whether or not import works with double quoted values and escaped
+// double quotes.
+//
+// Relies on test6.csv
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#ifdef HAVE_IOSTREAM
+# include <iostream>
+#endif
+
+#include <csvimport.h>
+
+#include "testpaths.h"
+
+int main (int, char**) {
+    try {
+	std::cout << "Importing from test6.csv" << std::endl;;
+	CSVImport imp(SRCDIR "/test6.csv", "test6.pet", ',');
+	imp.import("test6");
+	if (imp.hadErrors())
+	    return 1;
+	if (imp.numErrors() != 0)
+	    return 1;
+    } catch(std::exception& ex) {
+	std::cout << ex.what() << std::endl;
+	return 1;
+    }
+
+    return 0;
+}
diff -ruN yapet-0.4.bak/tests/Makefile.am yapet-0.4/tests/Makefile.am
--- yapet-0.4.bak/tests/Makefile.am	2009-07-11 23:06:38.000000000 +0200
+++ yapet-0.4/tests/Makefile.am	2009-07-18 22:46:06.140693748 +0200
@@ -1,12 +1,15 @@
 # $Id: Makefile.am 2464 2009-07-11 21:06:38Z rafi $
 
-DISTCLEANFILES = testfile.gps encryptiontest.gps encryptiontest.gps.bak	\
-test1.pet test2.pet test3.pet test4.pet
-EXTRA_DIST = test1.csv test2.csv test3.csv test4.csv
+DISTCLEANFILES = testfile.gps encryptiontest.gps encryptiontest.gps.bak		\
+test1.pet test2.pet test3.pet test4.pet test5.pet test6.pet test7.pet test8.pet	\
+test9.pet
+EXTRA_DIST = test1.csv test2.csv test3.csv test4.csv test5.csv test6.csv	\
+test7.csv test8.csv test9.csv
 
 check_PROGRAMS = key record bdbuffer enc partdec file file2 file3 file4 file5
 if BUILDCSV2YAPET
-check_PROGRAMS += import1 import2 import3 import4 import5 import6
+check_PROGRAMS += import1 import2 import3 import4 import5 import6 import7	\
+import8 import9 import10 import11 import12 import13 import14
 endif
 
 TESTS = $(check_PROGRAMS)
@@ -73,6 +76,38 @@
 import6_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
 import6_SOURCES = import6.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
 
+import7_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+import7_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+import7_SOURCES = import7.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+
+import8_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+import8_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+import8_SOURCES = import8.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+
+import9_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+import9_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+import9_SOURCES = import9.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+
+import10_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+import10_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+import10_SOURCES = import10.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+
+import11_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+import11_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+import11_SOURCES = import11.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+
+import12_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+import12_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+import12_SOURCES = import12.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+
+import13_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+import13_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+import13_SOURCES = import13.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+
+import14_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+import14_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+import14_SOURCES = import14.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+
 endif
 
 clean-local:
diff -ruN yapet-0.4.bak/tests/Makefile.in yapet-0.4/tests/Makefile.in
--- yapet-0.4.bak/tests/Makefile.in	2009-07-12 11:35:01.000000000 +0200
+++ yapet-0.4/tests/Makefile.in	2009-07-18 22:48:20.256602761 +0200
@@ -36,7 +36,9 @@
 check_PROGRAMS = key$(EXEEXT) record$(EXEEXT) bdbuffer$(EXEEXT) \
 	enc$(EXEEXT) partdec$(EXEEXT) file$(EXEEXT) file2$(EXEEXT) \
 	file3$(EXEEXT) file4$(EXEEXT) file5$(EXEEXT) $(am__EXEEXT_1)
-@BUILDCSV2YAPET_TRUE@am__append_1 = import1 import2 import3 import4 import5 import6
+@BUILDCSV2YAPET_TRUE@am__append_1 = import1 import2 import3 import4 import5 import6 import7	\
+@BUILDCSV2YAPET_TRUE@import8 import9 import10 import11 import12 import13 import14
+
 @USE_INCLUDED_LIBINTL_TRUE@am__append_2 = -I$(top_srcdir)/intl 
 subdir = tests
 DIST_COMMON = $(srcdir)/Makefile.am $(srcdir)/Makefile.in \
@@ -65,7 +67,11 @@
 CONFIG_CLEAN_FILES = testpaths.h
 @BUILDCSV2YAPET_TRUE@am__EXEEXT_1 = import1$(EXEEXT) import2$(EXEEXT) \
 @BUILDCSV2YAPET_TRUE@	import3$(EXEEXT) import4$(EXEEXT) \
-@BUILDCSV2YAPET_TRUE@	import5$(EXEEXT) import6$(EXEEXT)
+@BUILDCSV2YAPET_TRUE@	import5$(EXEEXT) import6$(EXEEXT) \
+@BUILDCSV2YAPET_TRUE@	import7$(EXEEXT) import8$(EXEEXT) \
+@BUILDCSV2YAPET_TRUE@	import9$(EXEEXT) import10$(EXEEXT) \
+@BUILDCSV2YAPET_TRUE@	import11$(EXEEXT) import12$(EXEEXT) \
+@BUILDCSV2YAPET_TRUE@	import13$(EXEEXT) import14$(EXEEXT)
 am_bdbuffer_OBJECTS = bdbuffer.$(OBJEXT)
 bdbuffer_OBJECTS = $(am_bdbuffer_OBJECTS)
 bdbuffer_DEPENDENCIES = $(top_builddir)/crypt/libgpcrypt.a
@@ -95,6 +101,51 @@
 import1_OBJECTS = $(am_import1_OBJECTS)
 @BUILDCSV2YAPET_TRUE@import1_DEPENDENCIES =  \
 @BUILDCSV2YAPET_TRUE@	$(top_builddir)/crypt/libgpcrypt.a
+am__import10_SOURCES_DIST = import10.cc \
+	$(top_builddir)/csv2yapet/csvimport.h \
+	$(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@am_import10_OBJECTS =  \
+@BUILDCSV2YAPET_TRUE@	import10-import10.$(OBJEXT) \
+@BUILDCSV2YAPET_TRUE@	import10-csvimport.$(OBJEXT)
+import10_OBJECTS = $(am_import10_OBJECTS)
+@BUILDCSV2YAPET_TRUE@import10_DEPENDENCIES =  \
+@BUILDCSV2YAPET_TRUE@	$(top_builddir)/crypt/libgpcrypt.a
+am__import11_SOURCES_DIST = import11.cc \
+	$(top_builddir)/csv2yapet/csvimport.h \
+	$(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@am_import11_OBJECTS =  \
+@BUILDCSV2YAPET_TRUE@	import11-import11.$(OBJEXT) \
+@BUILDCSV2YAPET_TRUE@	import11-csvimport.$(OBJEXT)
+import11_OBJECTS = $(am_import11_OBJECTS)
+@BUILDCSV2YAPET_TRUE@import11_DEPENDENCIES =  \
+@BUILDCSV2YAPET_TRUE@	$(top_builddir)/crypt/libgpcrypt.a
+am__import12_SOURCES_DIST = import12.cc \
+	$(top_builddir)/csv2yapet/csvimport.h \
+	$(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@am_import12_OBJECTS =  \
+@BUILDCSV2YAPET_TRUE@	import12-import12.$(OBJEXT) \
+@BUILDCSV2YAPET_TRUE@	import12-csvimport.$(OBJEXT)
+import12_OBJECTS = $(am_import12_OBJECTS)
+@BUILDCSV2YAPET_TRUE@import12_DEPENDENCIES =  \
+@BUILDCSV2YAPET_TRUE@	$(top_builddir)/crypt/libgpcrypt.a
+am__import13_SOURCES_DIST = import13.cc \
+	$(top_builddir)/csv2yapet/csvimport.h \
+	$(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@am_import13_OBJECTS =  \
+@BUILDCSV2YAPET_TRUE@	import13-import13.$(OBJEXT) \
+@BUILDCSV2YAPET_TRUE@	import13-csvimport.$(OBJEXT)
+import13_OBJECTS = $(am_import13_OBJECTS)
+@BUILDCSV2YAPET_TRUE@import13_DEPENDENCIES =  \
+@BUILDCSV2YAPET_TRUE@	$(top_builddir)/crypt/libgpcrypt.a
+am__import14_SOURCES_DIST = import14.cc \
+	$(top_builddir)/csv2yapet/csvimport.h \
+	$(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@am_import14_OBJECTS =  \
+@BUILDCSV2YAPET_TRUE@	import14-import14.$(OBJEXT) \
+@BUILDCSV2YAPET_TRUE@	import14-csvimport.$(OBJEXT)
+import14_OBJECTS = $(am_import14_OBJECTS)
+@BUILDCSV2YAPET_TRUE@import14_DEPENDENCIES =  \
+@BUILDCSV2YAPET_TRUE@	$(top_builddir)/crypt/libgpcrypt.a
 am__import2_SOURCES_DIST = import2.cc \
 	$(top_builddir)/csv2yapet/csvimport.h \
 	$(top_builddir)/csv2yapet/csvimport.cc
@@ -135,6 +186,30 @@
 import6_OBJECTS = $(am_import6_OBJECTS)
 @BUILDCSV2YAPET_TRUE@import6_DEPENDENCIES =  \
 @BUILDCSV2YAPET_TRUE@	$(top_builddir)/crypt/libgpcrypt.a
+am__import7_SOURCES_DIST = import7.cc \
+	$(top_builddir)/csv2yapet/csvimport.h \
+	$(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@am_import7_OBJECTS = import7-import7.$(OBJEXT) \
+@BUILDCSV2YAPET_TRUE@	import7-csvimport.$(OBJEXT)
+import7_OBJECTS = $(am_import7_OBJECTS)
+@BUILDCSV2YAPET_TRUE@import7_DEPENDENCIES =  \
+@BUILDCSV2YAPET_TRUE@	$(top_builddir)/crypt/libgpcrypt.a
+am__import8_SOURCES_DIST = import8.cc \
+	$(top_builddir)/csv2yapet/csvimport.h \
+	$(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@am_import8_OBJECTS = import8-import8.$(OBJEXT) \
+@BUILDCSV2YAPET_TRUE@	import8-csvimport.$(OBJEXT)
+import8_OBJECTS = $(am_import8_OBJECTS)
+@BUILDCSV2YAPET_TRUE@import8_DEPENDENCIES =  \
+@BUILDCSV2YAPET_TRUE@	$(top_builddir)/crypt/libgpcrypt.a
+am__import9_SOURCES_DIST = import9.cc \
+	$(top_builddir)/csv2yapet/csvimport.h \
+	$(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@am_import9_OBJECTS = import9-import9.$(OBJEXT) \
+@BUILDCSV2YAPET_TRUE@	import9-csvimport.$(OBJEXT)
+import9_OBJECTS = $(am_import9_OBJECTS)
+@BUILDCSV2YAPET_TRUE@import9_DEPENDENCIES =  \
+@BUILDCSV2YAPET_TRUE@	$(top_builddir)/crypt/libgpcrypt.a
 am_key_OBJECTS = key.$(OBJEXT)
 key_OBJECTS = $(am_key_OBJECTS)
 key_DEPENDENCIES = $(top_builddir)/crypt/libgpcrypt.a
@@ -158,16 +233,22 @@
 LINK = $(CCLD) $(AM_CFLAGS) $(CFLAGS) $(AM_LDFLAGS) $(LDFLAGS) -o $@
 SOURCES = $(bdbuffer_SOURCES) $(enc_SOURCES) $(file_SOURCES) \
 	$(file2_SOURCES) $(file3_SOURCES) $(file4_SOURCES) \
-	$(file5_SOURCES) $(import1_SOURCES) $(import2_SOURCES) \
-	$(import3_SOURCES) $(import4_SOURCES) $(import5_SOURCES) \
-	$(import6_SOURCES) $(key_SOURCES) $(partdec_SOURCES) \
-	$(record_SOURCES)
+	$(file5_SOURCES) $(import1_SOURCES) $(import10_SOURCES) \
+	$(import11_SOURCES) $(import12_SOURCES) $(import13_SOURCES) \
+	$(import14_SOURCES) $(import2_SOURCES) $(import3_SOURCES) \
+	$(import4_SOURCES) $(import5_SOURCES) $(import6_SOURCES) \
+	$(import7_SOURCES) $(import8_SOURCES) $(import9_SOURCES) \
+	$(key_SOURCES) $(partdec_SOURCES) $(record_SOURCES)
 DIST_SOURCES = $(bdbuffer_SOURCES) $(enc_SOURCES) $(file_SOURCES) \
 	$(file2_SOURCES) $(file3_SOURCES) $(file4_SOURCES) \
 	$(file5_SOURCES) $(am__import1_SOURCES_DIST) \
-	$(am__import2_SOURCES_DIST) $(am__import3_SOURCES_DIST) \
-	$(am__import4_SOURCES_DIST) $(am__import5_SOURCES_DIST) \
-	$(am__import6_SOURCES_DIST) $(key_SOURCES) $(partdec_SOURCES) \
+	$(am__import10_SOURCES_DIST) $(am__import11_SOURCES_DIST) \
+	$(am__import12_SOURCES_DIST) $(am__import13_SOURCES_DIST) \
+	$(am__import14_SOURCES_DIST) $(am__import2_SOURCES_DIST) \
+	$(am__import3_SOURCES_DIST) $(am__import4_SOURCES_DIST) \
+	$(am__import5_SOURCES_DIST) $(am__import6_SOURCES_DIST) \
+	$(am__import7_SOURCES_DIST) $(am__import8_SOURCES_DIST) \
+	$(am__import9_SOURCES_DIST) $(key_SOURCES) $(partdec_SOURCES) \
 	$(record_SOURCES)
 ETAGS = etags
 CTAGS = ctags
@@ -323,10 +404,13 @@
 top_build_prefix = @top_build_prefix@
 top_builddir = @top_builddir@
 top_srcdir = @top_srcdir@
-DISTCLEANFILES = testfile.gps encryptiontest.gps encryptiontest.gps.bak	\
-test1.pet test2.pet test3.pet test4.pet
+DISTCLEANFILES = testfile.gps encryptiontest.gps encryptiontest.gps.bak		\
+test1.pet test2.pet test3.pet test4.pet test5.pet test6.pet test7.pet test8.pet	\
+test9.pet
+
+EXTRA_DIST = test1.csv test2.csv test3.csv test4.csv test5.csv test6.csv	\
+test7.csv test8.csv test9.csv
 
-EXTRA_DIST = test1.csv test2.csv test3.csv test4.csv
 TESTS = $(check_PROGRAMS)
 AM_CPPFLAGS = -I$(top_srcdir)/crypt $(am__append_2)
 key_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
@@ -367,6 +451,30 @@
 @BUILDCSV2YAPET_TRUE@import6_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
 @BUILDCSV2YAPET_TRUE@import6_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
 @BUILDCSV2YAPET_TRUE@import6_SOURCES = import6.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@import7_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+@BUILDCSV2YAPET_TRUE@import7_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+@BUILDCSV2YAPET_TRUE@import7_SOURCES = import7.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@import8_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+@BUILDCSV2YAPET_TRUE@import8_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+@BUILDCSV2YAPET_TRUE@import8_SOURCES = import8.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@import9_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+@BUILDCSV2YAPET_TRUE@import9_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+@BUILDCSV2YAPET_TRUE@import9_SOURCES = import9.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@import10_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+@BUILDCSV2YAPET_TRUE@import10_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+@BUILDCSV2YAPET_TRUE@import10_SOURCES = import10.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@import11_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+@BUILDCSV2YAPET_TRUE@import11_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+@BUILDCSV2YAPET_TRUE@import11_SOURCES = import11.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@import12_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+@BUILDCSV2YAPET_TRUE@import12_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+@BUILDCSV2YAPET_TRUE@import12_SOURCES = import12.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@import13_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+@BUILDCSV2YAPET_TRUE@import13_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+@BUILDCSV2YAPET_TRUE@import13_SOURCES = import13.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
+@BUILDCSV2YAPET_TRUE@import14_LDADD = $(top_builddir)/crypt/libgpcrypt.a @LIBINTL@
+@BUILDCSV2YAPET_TRUE@import14_CPPFLAGS = $(AM_CPPFLAGS) -I$(top_srcdir)/csv2yapet -I$(top_srcdir)/crypt
+@BUILDCSV2YAPET_TRUE@import14_SOURCES = import14.cc $(top_builddir)/csv2yapet/csvimport.h $(top_builddir)/csv2yapet/csvimport.cc
 all: all-am
 
 .SUFFIXES:
@@ -429,6 +537,21 @@
 import1$(EXEEXT): $(import1_OBJECTS) $(import1_DEPENDENCIES) 
 	@rm -f import1$(EXEEXT)
 	$(CXXLINK) $(import1_OBJECTS) $(import1_LDADD) $(LIBS)
+import10$(EXEEXT): $(import10_OBJECTS) $(import10_DEPENDENCIES) 
+	@rm -f import10$(EXEEXT)
+	$(CXXLINK) $(import10_OBJECTS) $(import10_LDADD) $(LIBS)
+import11$(EXEEXT): $(import11_OBJECTS) $(import11_DEPENDENCIES) 
+	@rm -f import11$(EXEEXT)
+	$(CXXLINK) $(import11_OBJECTS) $(import11_LDADD) $(LIBS)
+import12$(EXEEXT): $(import12_OBJECTS) $(import12_DEPENDENCIES) 
+	@rm -f import12$(EXEEXT)
+	$(CXXLINK) $(import12_OBJECTS) $(import12_LDADD) $(LIBS)
+import13$(EXEEXT): $(import13_OBJECTS) $(import13_DEPENDENCIES) 
+	@rm -f import13$(EXEEXT)
+	$(CXXLINK) $(import13_OBJECTS) $(import13_LDADD) $(LIBS)
+import14$(EXEEXT): $(import14_OBJECTS) $(import14_DEPENDENCIES) 
+	@rm -f import14$(EXEEXT)
+	$(CXXLINK) $(import14_OBJECTS) $(import14_LDADD) $(LIBS)
 import2$(EXEEXT): $(import2_OBJECTS) $(import2_DEPENDENCIES) 
 	@rm -f import2$(EXEEXT)
 	$(CXXLINK) $(import2_OBJECTS) $(import2_LDADD) $(LIBS)
@@ -444,6 +567,15 @@
 import6$(EXEEXT): $(import6_OBJECTS) $(import6_DEPENDENCIES) 
 	@rm -f import6$(EXEEXT)
 	$(CXXLINK) $(import6_OBJECTS) $(import6_LDADD) $(LIBS)
+import7$(EXEEXT): $(import7_OBJECTS) $(import7_DEPENDENCIES) 
+	@rm -f import7$(EXEEXT)
+	$(CXXLINK) $(import7_OBJECTS) $(import7_LDADD) $(LIBS)
+import8$(EXEEXT): $(import8_OBJECTS) $(import8_DEPENDENCIES) 
+	@rm -f import8$(EXEEXT)
+	$(CXXLINK) $(import8_OBJECTS) $(import8_LDADD) $(LIBS)
+import9$(EXEEXT): $(import9_OBJECTS) $(import9_DEPENDENCIES) 
+	@rm -f import9$(EXEEXT)
+	$(CXXLINK) $(import9_OBJECTS) $(import9_LDADD) $(LIBS)
 key$(EXEEXT): $(key_OBJECTS) $(key_DEPENDENCIES) 
 	@rm -f key$(EXEEXT)
 	$(CXXLINK) $(key_OBJECTS) $(key_LDADD) $(LIBS)
@@ -469,6 +601,16 @@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/file5.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import1-csvimport.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import1-import1.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import10-csvimport.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import10-import10.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import11-csvimport.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import11-import11.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import12-csvimport.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import12-import12.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import13-csvimport.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import13-import13.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import14-csvimport.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import14-import14.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import2-csvimport.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import2-import2.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import3-csvimport.Po@am__quote@
@@ -479,6 +621,12 @@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import5-import5.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import6-csvimport.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import6-import6.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import7-csvimport.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import7-import7.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import8-csvimport.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import8-import8.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import9-csvimport.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/import9-import9.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/key.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/partdec.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/record.Po@am__quote@
@@ -525,6 +673,146 @@
 @AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import1_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import1-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
 
+import10-import10.o: import10.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import10_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import10-import10.o -MD -MP -MF $(DEPDIR)/import10-import10.Tpo -c -o import10-import10.o `test -f 'import10.cc' || echo '$(srcdir)/'`import10.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import10-import10.Tpo $(DEPDIR)/import10-import10.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import10.cc' object='import10-import10.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import10_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import10-import10.o `test -f 'import10.cc' || echo '$(srcdir)/'`import10.cc
+
+import10-import10.obj: import10.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import10_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import10-import10.obj -MD -MP -MF $(DEPDIR)/import10-import10.Tpo -c -o import10-import10.obj `if test -f 'import10.cc'; then $(CYGPATH_W) 'import10.cc'; else $(CYGPATH_W) '$(srcdir)/import10.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import10-import10.Tpo $(DEPDIR)/import10-import10.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import10.cc' object='import10-import10.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import10_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import10-import10.obj `if test -f 'import10.cc'; then $(CYGPATH_W) 'import10.cc'; else $(CYGPATH_W) '$(srcdir)/import10.cc'; fi`
+
+import10-csvimport.o: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import10_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import10-csvimport.o -MD -MP -MF $(DEPDIR)/import10-csvimport.Tpo -c -o import10-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import10-csvimport.Tpo $(DEPDIR)/import10-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import10-csvimport.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import10_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import10-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+
+import10-csvimport.obj: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import10_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import10-csvimport.obj -MD -MP -MF $(DEPDIR)/import10-csvimport.Tpo -c -o import10-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import10-csvimport.Tpo $(DEPDIR)/import10-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import10-csvimport.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import10_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import10-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+
+import11-import11.o: import11.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import11_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import11-import11.o -MD -MP -MF $(DEPDIR)/import11-import11.Tpo -c -o import11-import11.o `test -f 'import11.cc' || echo '$(srcdir)/'`import11.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import11-import11.Tpo $(DEPDIR)/import11-import11.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import11.cc' object='import11-import11.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import11_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import11-import11.o `test -f 'import11.cc' || echo '$(srcdir)/'`import11.cc
+
+import11-import11.obj: import11.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import11_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import11-import11.obj -MD -MP -MF $(DEPDIR)/import11-import11.Tpo -c -o import11-import11.obj `if test -f 'import11.cc'; then $(CYGPATH_W) 'import11.cc'; else $(CYGPATH_W) '$(srcdir)/import11.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import11-import11.Tpo $(DEPDIR)/import11-import11.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import11.cc' object='import11-import11.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import11_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import11-import11.obj `if test -f 'import11.cc'; then $(CYGPATH_W) 'import11.cc'; else $(CYGPATH_W) '$(srcdir)/import11.cc'; fi`
+
+import11-csvimport.o: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import11_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import11-csvimport.o -MD -MP -MF $(DEPDIR)/import11-csvimport.Tpo -c -o import11-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import11-csvimport.Tpo $(DEPDIR)/import11-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import11-csvimport.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import11_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import11-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+
+import11-csvimport.obj: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import11_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import11-csvimport.obj -MD -MP -MF $(DEPDIR)/import11-csvimport.Tpo -c -o import11-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import11-csvimport.Tpo $(DEPDIR)/import11-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import11-csvimport.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import11_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import11-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+
+import12-import12.o: import12.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import12_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import12-import12.o -MD -MP -MF $(DEPDIR)/import12-import12.Tpo -c -o import12-import12.o `test -f 'import12.cc' || echo '$(srcdir)/'`import12.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import12-import12.Tpo $(DEPDIR)/import12-import12.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import12.cc' object='import12-import12.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import12_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import12-import12.o `test -f 'import12.cc' || echo '$(srcdir)/'`import12.cc
+
+import12-import12.obj: import12.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import12_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import12-import12.obj -MD -MP -MF $(DEPDIR)/import12-import12.Tpo -c -o import12-import12.obj `if test -f 'import12.cc'; then $(CYGPATH_W) 'import12.cc'; else $(CYGPATH_W) '$(srcdir)/import12.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import12-import12.Tpo $(DEPDIR)/import12-import12.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import12.cc' object='import12-import12.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import12_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import12-import12.obj `if test -f 'import12.cc'; then $(CYGPATH_W) 'import12.cc'; else $(CYGPATH_W) '$(srcdir)/import12.cc'; fi`
+
+import12-csvimport.o: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import12_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import12-csvimport.o -MD -MP -MF $(DEPDIR)/import12-csvimport.Tpo -c -o import12-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import12-csvimport.Tpo $(DEPDIR)/import12-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import12-csvimport.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import12_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import12-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+
+import12-csvimport.obj: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import12_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import12-csvimport.obj -MD -MP -MF $(DEPDIR)/import12-csvimport.Tpo -c -o import12-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import12-csvimport.Tpo $(DEPDIR)/import12-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import12-csvimport.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import12_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import12-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+
+import13-import13.o: import13.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import13_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import13-import13.o -MD -MP -MF $(DEPDIR)/import13-import13.Tpo -c -o import13-import13.o `test -f 'import13.cc' || echo '$(srcdir)/'`import13.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import13-import13.Tpo $(DEPDIR)/import13-import13.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import13.cc' object='import13-import13.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import13_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import13-import13.o `test -f 'import13.cc' || echo '$(srcdir)/'`import13.cc
+
+import13-import13.obj: import13.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import13_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import13-import13.obj -MD -MP -MF $(DEPDIR)/import13-import13.Tpo -c -o import13-import13.obj `if test -f 'import13.cc'; then $(CYGPATH_W) 'import13.cc'; else $(CYGPATH_W) '$(srcdir)/import13.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import13-import13.Tpo $(DEPDIR)/import13-import13.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import13.cc' object='import13-import13.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import13_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import13-import13.obj `if test -f 'import13.cc'; then $(CYGPATH_W) 'import13.cc'; else $(CYGPATH_W) '$(srcdir)/import13.cc'; fi`
+
+import13-csvimport.o: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import13_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import13-csvimport.o -MD -MP -MF $(DEPDIR)/import13-csvimport.Tpo -c -o import13-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import13-csvimport.Tpo $(DEPDIR)/import13-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import13-csvimport.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import13_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import13-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+
+import13-csvimport.obj: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import13_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import13-csvimport.obj -MD -MP -MF $(DEPDIR)/import13-csvimport.Tpo -c -o import13-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import13-csvimport.Tpo $(DEPDIR)/import13-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import13-csvimport.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import13_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import13-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+
+import14-import14.o: import14.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import14_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import14-import14.o -MD -MP -MF $(DEPDIR)/import14-import14.Tpo -c -o import14-import14.o `test -f 'import14.cc' || echo '$(srcdir)/'`import14.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import14-import14.Tpo $(DEPDIR)/import14-import14.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import14.cc' object='import14-import14.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import14_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import14-import14.o `test -f 'import14.cc' || echo '$(srcdir)/'`import14.cc
+
+import14-import14.obj: import14.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import14_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import14-import14.obj -MD -MP -MF $(DEPDIR)/import14-import14.Tpo -c -o import14-import14.obj `if test -f 'import14.cc'; then $(CYGPATH_W) 'import14.cc'; else $(CYGPATH_W) '$(srcdir)/import14.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import14-import14.Tpo $(DEPDIR)/import14-import14.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import14.cc' object='import14-import14.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import14_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import14-import14.obj `if test -f 'import14.cc'; then $(CYGPATH_W) 'import14.cc'; else $(CYGPATH_W) '$(srcdir)/import14.cc'; fi`
+
+import14-csvimport.o: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import14_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import14-csvimport.o -MD -MP -MF $(DEPDIR)/import14-csvimport.Tpo -c -o import14-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import14-csvimport.Tpo $(DEPDIR)/import14-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import14-csvimport.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import14_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import14-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+
+import14-csvimport.obj: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import14_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import14-csvimport.obj -MD -MP -MF $(DEPDIR)/import14-csvimport.Tpo -c -o import14-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import14-csvimport.Tpo $(DEPDIR)/import14-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import14-csvimport.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import14_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import14-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+
 import2-import2.o: import2.cc
 @am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import2_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import2-import2.o -MD -MP -MF $(DEPDIR)/import2-import2.Tpo -c -o import2-import2.o `test -f 'import2.cc' || echo '$(srcdir)/'`import2.cc
 @am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import2-import2.Tpo $(DEPDIR)/import2-import2.Po
@@ -665,6 +953,90 @@
 @AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import6_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import6-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
 
+import7-import7.o: import7.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import7_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import7-import7.o -MD -MP -MF $(DEPDIR)/import7-import7.Tpo -c -o import7-import7.o `test -f 'import7.cc' || echo '$(srcdir)/'`import7.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import7-import7.Tpo $(DEPDIR)/import7-import7.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import7.cc' object='import7-import7.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import7_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import7-import7.o `test -f 'import7.cc' || echo '$(srcdir)/'`import7.cc
+
+import7-import7.obj: import7.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import7_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import7-import7.obj -MD -MP -MF $(DEPDIR)/import7-import7.Tpo -c -o import7-import7.obj `if test -f 'import7.cc'; then $(CYGPATH_W) 'import7.cc'; else $(CYGPATH_W) '$(srcdir)/import7.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import7-import7.Tpo $(DEPDIR)/import7-import7.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import7.cc' object='import7-import7.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import7_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import7-import7.obj `if test -f 'import7.cc'; then $(CYGPATH_W) 'import7.cc'; else $(CYGPATH_W) '$(srcdir)/import7.cc'; fi`
+
+import7-csvimport.o: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import7_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import7-csvimport.o -MD -MP -MF $(DEPDIR)/import7-csvimport.Tpo -c -o import7-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import7-csvimport.Tpo $(DEPDIR)/import7-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import7-csvimport.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import7_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import7-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+
+import7-csvimport.obj: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import7_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import7-csvimport.obj -MD -MP -MF $(DEPDIR)/import7-csvimport.Tpo -c -o import7-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import7-csvimport.Tpo $(DEPDIR)/import7-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import7-csvimport.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import7_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import7-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+
+import8-import8.o: import8.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import8_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import8-import8.o -MD -MP -MF $(DEPDIR)/import8-import8.Tpo -c -o import8-import8.o `test -f 'import8.cc' || echo '$(srcdir)/'`import8.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import8-import8.Tpo $(DEPDIR)/import8-import8.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import8.cc' object='import8-import8.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import8_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import8-import8.o `test -f 'import8.cc' || echo '$(srcdir)/'`import8.cc
+
+import8-import8.obj: import8.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import8_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import8-import8.obj -MD -MP -MF $(DEPDIR)/import8-import8.Tpo -c -o import8-import8.obj `if test -f 'import8.cc'; then $(CYGPATH_W) 'import8.cc'; else $(CYGPATH_W) '$(srcdir)/import8.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import8-import8.Tpo $(DEPDIR)/import8-import8.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import8.cc' object='import8-import8.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import8_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import8-import8.obj `if test -f 'import8.cc'; then $(CYGPATH_W) 'import8.cc'; else $(CYGPATH_W) '$(srcdir)/import8.cc'; fi`
+
+import8-csvimport.o: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import8_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import8-csvimport.o -MD -MP -MF $(DEPDIR)/import8-csvimport.Tpo -c -o import8-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import8-csvimport.Tpo $(DEPDIR)/import8-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import8-csvimport.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import8_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import8-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+
+import8-csvimport.obj: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import8_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import8-csvimport.obj -MD -MP -MF $(DEPDIR)/import8-csvimport.Tpo -c -o import8-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import8-csvimport.Tpo $(DEPDIR)/import8-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import8-csvimport.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import8_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import8-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+
+import9-import9.o: import9.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import9_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import9-import9.o -MD -MP -MF $(DEPDIR)/import9-import9.Tpo -c -o import9-import9.o `test -f 'import9.cc' || echo '$(srcdir)/'`import9.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import9-import9.Tpo $(DEPDIR)/import9-import9.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import9.cc' object='import9-import9.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import9_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import9-import9.o `test -f 'import9.cc' || echo '$(srcdir)/'`import9.cc
+
+import9-import9.obj: import9.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import9_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import9-import9.obj -MD -MP -MF $(DEPDIR)/import9-import9.Tpo -c -o import9-import9.obj `if test -f 'import9.cc'; then $(CYGPATH_W) 'import9.cc'; else $(CYGPATH_W) '$(srcdir)/import9.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import9-import9.Tpo $(DEPDIR)/import9-import9.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='import9.cc' object='import9-import9.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import9_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import9-import9.obj `if test -f 'import9.cc'; then $(CYGPATH_W) 'import9.cc'; else $(CYGPATH_W) '$(srcdir)/import9.cc'; fi`
+
+import9-csvimport.o: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import9_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import9-csvimport.o -MD -MP -MF $(DEPDIR)/import9-csvimport.Tpo -c -o import9-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import9-csvimport.Tpo $(DEPDIR)/import9-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import9-csvimport.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import9_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import9-csvimport.o `test -f '$(top_builddir)/csv2yapet/csvimport.cc' || echo '$(srcdir)/'`$(top_builddir)/csv2yapet/csvimport.cc
+
+import9-csvimport.obj: $(top_builddir)/csv2yapet/csvimport.cc
+@am__fastdepCXX_TRUE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import9_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT import9-csvimport.obj -MD -MP -MF $(DEPDIR)/import9-csvimport.Tpo -c -o import9-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+@am__fastdepCXX_TRUE@	mv -f $(DEPDIR)/import9-csvimport.Tpo $(DEPDIR)/import9-csvimport.Po
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(top_builddir)/csv2yapet/csvimport.cc' object='import9-csvimport.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	DEPDIR=$(DEPDIR) $(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(import9_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o import9-csvimport.obj `if test -f '$(top_builddir)/csv2yapet/csvimport.cc'; then $(CYGPATH_W) '$(top_builddir)/csv2yapet/csvimport.cc'; else $(CYGPATH_W) '$(srcdir)/$(top_builddir)/csv2yapet/csvimport.cc'; fi`
+
 ID: $(HEADERS) $(SOURCES) $(LISP) $(TAGS_FILES)
 	list='$(SOURCES) $(HEADERS) $(LISP) $(TAGS_FILES)'; \
 	unique=`for i in $$list; do \
diff -ruN yapet-0.4.bak/tests/test5.csv yapet-0.4/tests/test5.csv
--- yapet-0.4.bak/tests/test5.csv	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/test5.csv	2009-07-18 20:33:55.512724390 +0200
@@ -0,0 +1,200 @@
+"Test name 0","Test host 0","Test username 0","Test password 0","Test comment 0"
+"Test name 1","Test host 1","Test username 1","Test password 1","Test comment 1"
+"Test name 2","Test host 2","Test username 2","Test password 2","Test comment 2"
+"Test name 3","Test host 3","Test username 3","Test password 3","Test comment 3"
+"Test name 4","Test host 4","Test username 4","Test password 4","Test comment 4"
+"Test name 5","Test host 5","Test username 5","Test password 5","Test comment 5"
+"Test name 6","Test host 6","Test username 6","Test password 6","Test comment 6"
+"Test name 7","Test host 7","Test username 7","Test password 7","Test comment 7"
+"Test name 8","Test host 8","Test username 8","Test password 8","Test comment 8"
+"Test name 9","Test host 9","Test username 9","Test password 9","Test comment 9"
+"Test name 10","Test host 10","Test username 10","Test password 10","Test comment 10"
+"Test name 11","Test host 11","Test username 11","Test password 11","Test comment 11"
+"Test name 12","Test host 12","Test username 12","Test password 12","Test comment 12"
+"Test name 13","Test host 13","Test username 13","Test password 13","Test comment 13"
+"Test name 14","Test host 14","Test username 14","Test password 14","Test comment 14"
+"Test name 15","Test host 15","Test username 15","Test password 15","Test comment 15"
+"Test name 16","Test host 16","Test username 16","Test password 16","Test comment 16"
+"Test name 17","Test host 17","Test username 17","Test password 17","Test comment 17"
+"Test name 18","Test host 18","Test username 18","Test password 18","Test comment 18"
+"Test name 19","Test host 19","Test username 19","Test password 19","Test comment 19"
+"Test name 20","Test host 20","Test username 20","Test password 20","Test comment 20"
+"Test name 21","Test host 21","Test username 21","Test password 21","Test comment 21"
+"Test name 22","Test host 22","Test username 22","Test password 22","Test comment 22"
+"Test name 23","Test host 23","Test username 23","Test password 23","Test comment 23"
+"Test name 24","Test host 24","Test username 24","Test password 24","Test comment 24"
+"Test name 25","Test host 25","Test username 25","Test password 25","Test comment 25"
+"Test name 26","Test host 26","Test username 26","Test password 26","Test comment 26"
+"Test name 27","Test host 27","Test username 27","Test password 27","Test comment 27"
+"Test name 28","Test host 28","Test username 28","Test password 28","Test comment 28"
+"Test name 29","Test host 29","Test username 29","Test password 29","Test comment 29"
+"Test name 30","Test host 30","Test username 30","Test password 30","Test comment 30"
+"Test name 31","Test host 31","Test username 31","Test password 31","Test comment 31"
+"Test name 32","Test host 32","Test username 32","Test password 32","Test comment 32"
+"Test name 33","Test host 33","Test username 33","Test password 33","Test comment 33"
+"Test name 34","Test host 34","Test username 34","Test password 34","Test comment 34"
+"Test name 35","Test host 35","Test username 35","Test password 35","Test comment 35"
+"Test name 36","Test host 36","Test username 36","Test password 36","Test comment 36"
+"Test name 37","Test host 37","Test username 37","Test password 37","Test comment 37"
+"Test name 38","Test host 38","Test username 38","Test password 38","Test comment 38"
+"Test name 39","Test host 39","Test username 39","Test password 39","Test comment 39"
+"Test name 40","Test host 40","Test username 40","Test password 40","Test comment 40"
+"Test name 41","Test host 41","Test username 41","Test password 41","Test comment 41"
+"Test name 42","Test host 42","Test username 42","Test password 42","Test comment 42"
+"Test name 43","Test host 43","Test username 43","Test password 43","Test comment 43"
+"Test name 44","Test host 44","Test username 44","Test password 44","Test comment 44"
+"Test name 45","Test host 45","Test username 45","Test password 45","Test comment 45"
+"Test name 46","Test host 46","Test username 46","Test password 46","Test comment 46"
+"Test name 47","Test host 47","Test username 47","Test password 47","Test comment 47"
+"Test name 48","Test host 48","Test username 48","Test password 48","Test comment 48"
+"Test name 49","Test host 49","Test username 49","Test password 49","Test comment 49"
+"Test name 50","Test host 50","Test username 50","Test password 50","Test comment 50"
+"Test name 51","Test host 51","Test username 51","Test password 51","Test comment 51"
+"Test name 52","Test host 52","Test username 52","Test password 52","Test comment 52"
+"Test name 53","Test host 53","Test username 53","Test password 53","Test comment 53"
+"Test name 54","Test host 54","Test username 54","Test password 54","Test comment 54"
+"Test name 55","Test host 55","Test username 55","Test password 55","Test comment 55"
+"Test name 56","Test host 56","Test username 56","Test password 56","Test comment 56"
+"Test name 57","Test host 57","Test username 57","Test password 57","Test comment 57"
+"Test name 58","Test host 58","Test username 58","Test password 58","Test comment 58"
+"Test name 59","Test host 59","Test username 59","Test password 59","Test comment 59"
+"Test name 60","Test host 60","Test username 60","Test password 60","Test comment 60"
+"Test name 61","Test host 61","Test username 61","Test password 61","Test comment 61"
+"Test name 62","Test host 62","Test username 62","Test password 62","Test comment 62"
+"Test name 63","Test host 63","Test username 63","Test password 63","Test comment 63"
+"Test name 64","Test host 64","Test username 64","Test password 64","Test comment 64"
+"Test name 65","Test host 65","Test username 65","Test password 65","Test comment 65"
+"Test name 66","Test host 66","Test username 66","Test password 66","Test comment 66"
+"Test name 67","Test host 67","Test username 67","Test password 67","Test comment 67"
+"Test name 68","Test host 68","Test username 68","Test password 68","Test comment 68"
+"Test name 69","Test host 69","Test username 69","Test password 69","Test comment 69"
+"Test name 70","Test host 70","Test username 70","Test password 70","Test comment 70"
+"Test name 71","Test host 71","Test username 71","Test password 71","Test comment 71"
+"Test name 72","Test host 72","Test username 72","Test password 72","Test comment 72"
+"Test name 73","Test host 73","Test username 73","Test password 73","Test comment 73"
+"Test name 74","Test host 74","Test username 74","Test password 74","Test comment 74"
+"Test name 75","Test host 75","Test username 75","Test password 75","Test comment 75"
+"Test name 76","Test host 76","Test username 76","Test password 76","Test comment 76"
+"Test name 77","Test host 77","Test username 77","Test password 77","Test comment 77"
+"Test name 78","Test host 78","Test username 78","Test password 78","Test comment 78"
+"Test name 79","Test host 79","Test username 79","Test password 79","Test comment 79"
+"Test name 80","Test host 80","Test username 80","Test password 80","Test comment 80"
+"Test name 81","Test host 81","Test username 81","Test password 81","Test comment 81"
+"Test name 82","Test host 82","Test username 82","Test password 82","Test comment 82"
+"Test name 83","Test host 83","Test username 83","Test password 83","Test comment 83"
+"Test name 84","Test host 84","Test username 84","Test password 84","Test comment 84"
+"Test name 85","Test host 85","Test username 85","Test password 85","Test comment 85"
+"Test name 86","Test host 86","Test username 86","Test password 86","Test comment 86"
+"Test name 87","Test host 87","Test username 87","Test password 87","Test comment 87"
+"Test name 88","Test host 88","Test username 88","Test password 88","Test comment 88"
+"Test name 89","Test host 89","Test username 89","Test password 89","Test comment 89"
+"Test name 90","Test host 90","Test username 90","Test password 90","Test comment 90"
+"Test name 91","Test host 91","Test username 91","Test password 91","Test comment 91"
+"Test name 92","Test host 92","Test username 92","Test password 92","Test comment 92"
+"Test name 93","Test host 93","Test username 93","Test password 93","Test comment 93"
+"Test name 94","Test host 94","Test username 94","Test password 94","Test comment 94"
+"Test name 95","Test host 95","Test username 95","Test password 95","Test comment 95"
+"Test name 96","Test host 96","Test username 96","Test password 96","Test comment 96"
+"Test name 97","Test host 97","Test username 97","Test password 97","Test comment 97"
+"Test name 98","Test host 98","Test username 98","Test password 98","Test comment 98"
+"Test name 99","Test host 99","Test username 99","Test password 99","Test comment 99"
+"Test name 100","Test host 100","Test username 100","Test password 100","Test comment 100"
+"Test name 101","Test host 101","Test username 101","Test password 101","Test comment 101"
+"Test name 102","Test host 102","Test username 102","Test password 102","Test comment 102"
+"Test name 103","Test host 103","Test username 103","Test password 103","Test comment 103"
+"Test name 104","Test host 104","Test username 104","Test password 104","Test comment 104"
+"Test name 105","Test host 105","Test username 105","Test password 105","Test comment 105"
+"Test name 106","Test host 106","Test username 106","Test password 106","Test comment 106"
+"Test name 107","Test host 107","Test username 107","Test password 107","Test comment 107"
+"Test name 108","Test host 108","Test username 108","Test password 108","Test comment 108"
+"Test name 109","Test host 109","Test username 109","Test password 109","Test comment 109"
+"Test name 110","Test host 110","Test username 110","Test password 110","Test comment 110"
+"Test name 111","Test host 111","Test username 111","Test password 111","Test comment 111"
+"Test name 112","Test host 112","Test username 112","Test password 112","Test comment 112"
+"Test name 113","Test host 113","Test username 113","Test password 113","Test comment 113"
+"Test name 114","Test host 114","Test username 114","Test password 114","Test comment 114"
+"Test name 115","Test host 115","Test username 115","Test password 115","Test comment 115"
+"Test name 116","Test host 116","Test username 116","Test password 116","Test comment 116"
+"Test name 117","Test host 117","Test username 117","Test password 117","Test comment 117"
+"Test name 118","Test host 118","Test username 118","Test password 118","Test comment 118"
+"Test name 119","Test host 119","Test username 119","Test password 119","Test comment 119"
+"Test name 120","Test host 120","Test username 120","Test password 120","Test comment 120"
+"Test name 121","Test host 121","Test username 121","Test password 121","Test comment 121"
+"Test name 122","Test host 122","Test username 122","Test password 122","Test comment 122"
+"Test name 123","Test host 123","Test username 123","Test password 123","Test comment 123"
+"Test name 124","Test host 124","Test username 124","Test password 124","Test comment 124"
+"Test name 125","Test host 125","Test username 125","Test password 125","Test comment 125"
+"Test name 126","Test host 126","Test username 126","Test password 126","Test comment 126"
+"Test name 127","Test host 127","Test username 127","Test password 127","Test comment 127"
+"Test name 128","Test host 128","Test username 128","Test password 128","Test comment 128"
+"Test name 129","Test host 129","Test username 129","Test password 129","Test comment 129"
+"Test name 130","Test host 130","Test username 130","Test password 130","Test comment 130"
+"Test name 131","Test host 131","Test username 131","Test password 131","Test comment 131"
+"Test name 132","Test host 132","Test username 132","Test password 132","Test comment 132"
+"Test name 133","Test host 133","Test username 133","Test password 133","Test comment 133"
+"Test name 134","Test host 134","Test username 134","Test password 134","Test comment 134"
+"Test name 135","Test host 135","Test username 135","Test password 135","Test comment 135"
+"Test name 136","Test host 136","Test username 136","Test password 136","Test comment 136"
+"Test name 137","Test host 137","Test username 137","Test password 137","Test comment 137"
+"Test name 138","Test host 138","Test username 138","Test password 138","Test comment 138"
+"Test name 139","Test host 139","Test username 139","Test password 139","Test comment 139"
+"Test name 140","Test host 140","Test username 140","Test password 140","Test comment 140"
+"Test name 141","Test host 141","Test username 141","Test password 141","Test comment 141"
+"Test name 142","Test host 142","Test username 142","Test password 142","Test comment 142"
+"Test name 143","Test host 143","Test username 143","Test password 143","Test comment 143"
+"Test name 144","Test host 144","Test username 144","Test password 144","Test comment 144"
+"Test name 145","Test host 145","Test username 145","Test password 145","Test comment 145"
+"Test name 146","Test host 146","Test username 146","Test password 146","Test comment 146"
+"Test name 147","Test host 147","Test username 147","Test password 147","Test comment 147"
+"Test name 148","Test host 148","Test username 148","Test password 148","Test comment 148"
+"Test name 149","Test host 149","Test username 149","Test password 149","Test comment 149"
+"Test name 150","Test host 150","Test username 150","Test password 150","Test comment 150"
+"Test name 151","Test host 151","Test username 151","Test password 151","Test comment 151"
+"Test name 152","Test host 152","Test username 152","Test password 152","Test comment 152"
+"Test name 153","Test host 153","Test username 153","Test password 153","Test comment 153"
+"Test name 154","Test host 154","Test username 154","Test password 154","Test comment 154"
+"Test name 155","Test host 155","Test username 155","Test password 155","Test comment 155"
+"Test name 156","Test host 156","Test username 156","Test password 156","Test comment 156"
+"Test name 157","Test host 157","Test username 157","Test password 157","Test comment 157"
+"Test name 158","Test host 158","Test username 158","Test password 158","Test comment 158"
+"Test name 159","Test host 159","Test username 159","Test password 159","Test comment 159"
+"Test name 160","Test host 160","Test username 160","Test password 160","Test comment 160"
+"Test name 161","Test host 161","Test username 161","Test password 161","Test comment 161"
+"Test name 162","Test host 162","Test username 162","Test password 162","Test comment 162"
+"Test name 163","Test host 163","Test username 163","Test password 163","Test comment 163"
+"Test name 164","Test host 164","Test username 164","Test password 164","Test comment 164"
+"Test name 165","Test host 165","Test username 165","Test password 165","Test comment 165"
+"Test name 166","Test host 166","Test username 166","Test password 166","Test comment 166"
+"Test name 167","Test host 167","Test username 167","Test password 167","Test comment 167"
+"Test name 168","Test host 168","Test username 168","Test password 168","Test comment 168"
+"Test name 169","Test host 169","Test username 169","Test password 169","Test comment 169"
+"Test name 170","Test host 170","Test username 170","Test password 170","Test comment 170"
+"Test name 171","Test host 171","Test username 171","Test password 171","Test comment 171"
+"Test name 172","Test host 172","Test username 172","Test password 172","Test comment 172"
+"Test name 173","Test host 173","Test username 173","Test password 173","Test comment 173"
+"Test name 174","Test host 174","Test username 174","Test password 174","Test comment 174"
+"Test name 175","Test host 175","Test username 175","Test password 175","Test comment 175"
+"Test name 176","Test host 176","Test username 176","Test password 176","Test comment 176"
+"Test name 177","Test host 177","Test username 177","Test password 177","Test comment 177"
+"Test name 178","Test host 178","Test username 178","Test password 178","Test comment 178"
+"Test name 179","Test host 179","Test username 179","Test password 179","Test comment 179"
+"Test name 180","Test host 180","Test username 180","Test password 180","Test comment 180"
+"Test name 181","Test host 181","Test username 181","Test password 181","Test comment 181"
+"Test name 182","Test host 182","Test username 182","Test password 182","Test comment 182"
+"Test name 183","Test host 183","Test username 183","Test password 183","Test comment 183"
+"Test name 184","Test host 184","Test username 184","Test password 184","Test comment 184"
+"Test name 185","Test host 185","Test username 185","Test password 185","Test comment 185"
+"Test name 186","Test host 186","Test username 186","Test password 186","Test comment 186"
+"Test name 187","Test host 187","Test username 187","Test password 187","Test comment 187"
+"Test name 188","Test host 188","Test username 188","Test password 188","Test comment 188"
+"Test name 189","Test host 189","Test username 189","Test password 189","Test comment 189"
+"Test name 190","Test host 190","Test username 190","Test password 190","Test comment 190"
+"Test name 191","Test host 191","Test username 191","Test password 191","Test comment 191"
+"Test name 192","Test host 192","Test username 192","Test password 192","Test comment 192"
+"Test name 193","Test host 193","Test username 193","Test password 193","Test comment 193"
+"Test name 194","Test host 194","Test username 194","Test password 194","Test comment 194"
+"Test name 195","Test host 195","Test username 195","Test password 195","Test comment 195"
+"Test name 196","Test host 196","Test username 196","Test password 196","Test comment 196"
+"Test name 197","Test host 197","Test username 197","Test password 197","Test comment 197"
+"Test name 198","Test host 198","Test username 198","Test password 198","Test comment 198"
+"Test name 199","Test host 199","Test username 199","Test password 199","Test comment 199"
diff -ruN yapet-0.4.bak/tests/test6.csv yapet-0.4/tests/test6.csv
--- yapet-0.4.bak/tests/test6.csv	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/test6.csv	2009-07-18 22:15:44.012704021 +0200
@@ -0,0 +1,200 @@
+"""Test name 0","Test host 0""","Test ""username 0","Test ""password"" 0","Test """"comment 0"""""
+"""Test name 1","Test host 1""","Test ""username 1","Test ""password"" 1","Test """"comment 1"""""
+"""Test name 2","Test host 2""","Test ""username 2","Test ""password"" 2","Test """"comment 2"""""
+"""Test name 3","Test host 3""","Test ""username 3","Test ""password"" 3","Test """"comment 3"""""
+"""Test name 4","Test host 4""","Test ""username 4","Test ""password"" 4","Test """"comment 4"""""
+"""Test name 5","Test host 5""","Test ""username 5","Test ""password"" 5","Test """"comment 5"""""
+"""Test name 6","Test host 6""","Test ""username 6","Test ""password"" 6","Test """"comment 6"""""
+"""Test name 7","Test host 7""","Test ""username 7","Test ""password"" 7","Test """"comment 7"""""
+"""Test name 8","Test host 8""","Test ""username 8","Test ""password"" 8","Test """"comment 8"""""
+"""Test name 9","Test host 9""","Test ""username 9","Test ""password"" 9","Test """"comment 9"""""
+"""Test name 10","Test host 10""","Test ""username 10","Test ""password"" 10","Test """"comment 10"""""
+"""Test name 11","Test host 11""","Test ""username 11","Test ""password"" 11","Test """"comment 11"""""
+"""Test name 12","Test host 12""","Test ""username 12","Test ""password"" 12","Test """"comment 12"""""
+"""Test name 13","Test host 13""","Test ""username 13","Test ""password"" 13","Test """"comment 13"""""
+"""Test name 14","Test host 14""","Test ""username 14","Test ""password"" 14","Test """"comment 14"""""
+"""Test name 15","Test host 15""","Test ""username 15","Test ""password"" 15","Test """"comment 15"""""
+"""Test name 16","Test host 16""","Test ""username 16","Test ""password"" 16","Test """"comment 16"""""
+"""Test name 17","Test host 17""","Test ""username 17","Test ""password"" 17","Test """"comment 17"""""
+"""Test name 18","Test host 18""","Test ""username 18","Test ""password"" 18","Test """"comment 18"""""
+"""Test name 19","Test host 19""","Test ""username 19","Test ""password"" 19","Test """"comment 19"""""
+"""Test name 20","Test host 20""","Test ""username 20","Test ""password"" 20","Test """"comment 20"""""
+"""Test name 21","Test host 21""","Test ""username 21","Test ""password"" 21","Test """"comment 21"""""
+"""Test name 22","Test host 22""","Test ""username 22","Test ""password"" 22","Test """"comment 22"""""
+"""Test name 23","Test host 23""","Test ""username 23","Test ""password"" 23","Test """"comment 23"""""
+"""Test name 24","Test host 24""","Test ""username 24","Test ""password"" 24","Test """"comment 24"""""
+"""Test name 25","Test host 25""","Test ""username 25","Test ""password"" 25","Test """"comment 25"""""
+"""Test name 26","Test host 26""","Test ""username 26","Test ""password"" 26","Test """"comment 26"""""
+"""Test name 27","Test host 27""","Test ""username 27","Test ""password"" 27","Test """"comment 27"""""
+"""Test name 28","Test host 28""","Test ""username 28","Test ""password"" 28","Test """"comment 28"""""
+"""Test name 29","Test host 29""","Test ""username 29","Test ""password"" 29","Test """"comment 29"""""
+"""Test name 30","Test host 30""","Test ""username 30","Test ""password"" 30","Test """"comment 30"""""
+"""Test name 31","Test host 31""","Test ""username 31","Test ""password"" 31","Test """"comment 31"""""
+"""Test name 32","Test host 32""","Test ""username 32","Test ""password"" 32","Test """"comment 32"""""
+"""Test name 33","Test host 33""","Test ""username 33","Test ""password"" 33","Test """"comment 33"""""
+"""Test name 34","Test host 34""","Test ""username 34","Test ""password"" 34","Test """"comment 34"""""
+"""Test name 35","Test host 35""","Test ""username 35","Test ""password"" 35","Test """"comment 35"""""
+"""Test name 36","Test host 36""","Test ""username 36","Test ""password"" 36","Test """"comment 36"""""
+"""Test name 37","Test host 37""","Test ""username 37","Test ""password"" 37","Test """"comment 37"""""
+"""Test name 38","Test host 38""","Test ""username 38","Test ""password"" 38","Test """"comment 38"""""
+"""Test name 39","Test host 39""","Test ""username 39","Test ""password"" 39","Test """"comment 39"""""
+"""Test name 40","Test host 40""","Test ""username 40","Test ""password"" 40","Test """"comment 40"""""
+"""Test name 41","Test host 41""","Test ""username 41","Test ""password"" 41","Test """"comment 41"""""
+"""Test name 42","Test host 42""","Test ""username 42","Test ""password"" 42","Test """"comment 42"""""
+"""Test name 43","Test host 43""","Test ""username 43","Test ""password"" 43","Test """"comment 43"""""
+"""Test name 44","Test host 44""","Test ""username 44","Test ""password"" 44","Test """"comment 44"""""
+"""Test name 45","Test host 45""","Test ""username 45","Test ""password"" 45","Test """"comment 45"""""
+"""Test name 46","Test host 46""","Test ""username 46","Test ""password"" 46","Test """"comment 46"""""
+"""Test name 47","Test host 47""","Test ""username 47","Test ""password"" 47","Test """"comment 47"""""
+"""Test name 48","Test host 48""","Test ""username 48","Test ""password"" 48","Test """"comment 48"""""
+"""Test name 49","Test host 49""","Test ""username 49","Test ""password"" 49","Test """"comment 49"""""
+"""Test name 50","Test host 50""","Test ""username 50","Test ""password"" 50","Test """"comment 50"""""
+"""Test name 51","Test host 51""","Test ""username 51","Test ""password"" 51","Test """"comment 51"""""
+"""Test name 52","Test host 52""","Test ""username 52","Test ""password"" 52","Test """"comment 52"""""
+"""Test name 53","Test host 53""","Test ""username 53","Test ""password"" 53","Test """"comment 53"""""
+"""Test name 54","Test host 54""","Test ""username 54","Test ""password"" 54","Test """"comment 54"""""
+"""Test name 55","Test host 55""","Test ""username 55","Test ""password"" 55","Test """"comment 55"""""
+"""Test name 56","Test host 56""","Test ""username 56","Test ""password"" 56","Test """"comment 56"""""
+"""Test name 57","Test host 57""","Test ""username 57","Test ""password"" 57","Test """"comment 57"""""
+"""Test name 58","Test host 58""","Test ""username 58","Test ""password"" 58","Test """"comment 58"""""
+"""Test name 59","Test host 59""","Test ""username 59","Test ""password"" 59","Test """"comment 59"""""
+"""Test name 60","Test host 60""","Test ""username 60","Test ""password"" 60","Test """"comment 60"""""
+"""Test name 61","Test host 61""","Test ""username 61","Test ""password"" 61","Test """"comment 61"""""
+"""Test name 62","Test host 62""","Test ""username 62","Test ""password"" 62","Test """"comment 62"""""
+"""Test name 63","Test host 63""","Test ""username 63","Test ""password"" 63","Test """"comment 63"""""
+"""Test name 64","Test host 64""","Test ""username 64","Test ""password"" 64","Test """"comment 64"""""
+"""Test name 65","Test host 65""","Test ""username 65","Test ""password"" 65","Test """"comment 65"""""
+"""Test name 66","Test host 66""","Test ""username 66","Test ""password"" 66","Test """"comment 66"""""
+"""Test name 67","Test host 67""","Test ""username 67","Test ""password"" 67","Test """"comment 67"""""
+"""Test name 68","Test host 68""","Test ""username 68","Test ""password"" 68","Test """"comment 68"""""
+"""Test name 69","Test host 69""","Test ""username 69","Test ""password"" 69","Test """"comment 69"""""
+"""Test name 70","Test host 70""","Test ""username 70","Test ""password"" 70","Test """"comment 70"""""
+"""Test name 71","Test host 71""","Test ""username 71","Test ""password"" 71","Test """"comment 71"""""
+"""Test name 72","Test host 72""","Test ""username 72","Test ""password"" 72","Test """"comment 72"""""
+"""Test name 73","Test host 73""","Test ""username 73","Test ""password"" 73","Test """"comment 73"""""
+"""Test name 74","Test host 74""","Test ""username 74","Test ""password"" 74","Test """"comment 74"""""
+"""Test name 75","Test host 75""","Test ""username 75","Test ""password"" 75","Test """"comment 75"""""
+"""Test name 76","Test host 76""","Test ""username 76","Test ""password"" 76","Test """"comment 76"""""
+"""Test name 77","Test host 77""","Test ""username 77","Test ""password"" 77","Test """"comment 77"""""
+"""Test name 78","Test host 78""","Test ""username 78","Test ""password"" 78","Test """"comment 78"""""
+"""Test name 79","Test host 79""","Test ""username 79","Test ""password"" 79","Test """"comment 79"""""
+"""Test name 80","Test host 80""","Test ""username 80","Test ""password"" 80","Test """"comment 80"""""
+"""Test name 81","Test host 81""","Test ""username 81","Test ""password"" 81","Test """"comment 81"""""
+"""Test name 82","Test host 82""","Test ""username 82","Test ""password"" 82","Test """"comment 82"""""
+"""Test name 83","Test host 83""","Test ""username 83","Test ""password"" 83","Test """"comment 83"""""
+"""Test name 84","Test host 84""","Test ""username 84","Test ""password"" 84","Test """"comment 84"""""
+"""Test name 85","Test host 85""","Test ""username 85","Test ""password"" 85","Test """"comment 85"""""
+"""Test name 86","Test host 86""","Test ""username 86","Test ""password"" 86","Test """"comment 86"""""
+"""Test name 87","Test host 87""","Test ""username 87","Test ""password"" 87","Test """"comment 87"""""
+"""Test name 88","Test host 88""","Test ""username 88","Test ""password"" 88","Test """"comment 88"""""
+"""Test name 89","Test host 89""","Test ""username 89","Test ""password"" 89","Test """"comment 89"""""
+"""Test name 90","Test host 90""","Test ""username 90","Test ""password"" 90","Test """"comment 90"""""
+"""Test name 91","Test host 91""","Test ""username 91","Test ""password"" 91","Test """"comment 91"""""
+"""Test name 92","Test host 92""","Test ""username 92","Test ""password"" 92","Test """"comment 92"""""
+"""Test name 93","Test host 93""","Test ""username 93","Test ""password"" 93","Test """"comment 93"""""
+"""Test name 94","Test host 94""","Test ""username 94","Test ""password"" 94","Test """"comment 94"""""
+"""Test name 95","Test host 95""","Test ""username 95","Test ""password"" 95","Test """"comment 95"""""
+"""Test name 96","Test host 96""","Test ""username 96","Test ""password"" 96","Test """"comment 96"""""
+"""Test name 97","Test host 97""","Test ""username 97","Test ""password"" 97","Test """"comment 97"""""
+"""Test name 98","Test host 98""","Test ""username 98","Test ""password"" 98","Test """"comment 98"""""
+"""Test name 99","Test host 99""","Test ""username 99","Test ""password"" 99","Test """"comment 99"""""
+"""Test name 100","Test host 100""","Test ""username 100","Test ""password"" 100","Test """"comment 100"""""
+"""Test name 101","Test host 101""","Test ""username 101","Test ""password"" 101","Test """"comment 101"""""
+"""Test name 102","Test host 102""","Test ""username 102","Test ""password"" 102","Test """"comment 102"""""
+"""Test name 103","Test host 103""","Test ""username 103","Test ""password"" 103","Test """"comment 103"""""
+"""Test name 104","Test host 104""","Test ""username 104","Test ""password"" 104","Test """"comment 104"""""
+"""Test name 105","Test host 105""","Test ""username 105","Test ""password"" 105","Test """"comment 105"""""
+"""Test name 106","Test host 106""","Test ""username 106","Test ""password"" 106","Test """"comment 106"""""
+"""Test name 107","Test host 107""","Test ""username 107","Test ""password"" 107","Test """"comment 107"""""
+"""Test name 108","Test host 108""","Test ""username 108","Test ""password"" 108","Test """"comment 108"""""
+"""Test name 109","Test host 109""","Test ""username 109","Test ""password"" 109","Test """"comment 109"""""
+"""Test name 110","Test host 110""","Test ""username 110","Test ""password"" 110","Test """"comment 110"""""
+"""Test name 111","Test host 111""","Test ""username 111","Test ""password"" 111","Test """"comment 111"""""
+"""Test name 112","Test host 112""","Test ""username 112","Test ""password"" 112","Test """"comment 112"""""
+"""Test name 113","Test host 113""","Test ""username 113","Test ""password"" 113","Test """"comment 113"""""
+"""Test name 114","Test host 114""","Test ""username 114","Test ""password"" 114","Test """"comment 114"""""
+"""Test name 115","Test host 115""","Test ""username 115","Test ""password"" 115","Test """"comment 115"""""
+"""Test name 116","Test host 116""","Test ""username 116","Test ""password"" 116","Test """"comment 116"""""
+"""Test name 117","Test host 117""","Test ""username 117","Test ""password"" 117","Test """"comment 117"""""
+"""Test name 118","Test host 118""","Test ""username 118","Test ""password"" 118","Test """"comment 118"""""
+"""Test name 119","Test host 119""","Test ""username 119","Test ""password"" 119","Test """"comment 119"""""
+"""Test name 120","Test host 120""","Test ""username 120","Test ""password"" 120","Test """"comment 120"""""
+"""Test name 121","Test host 121""","Test ""username 121","Test ""password"" 121","Test """"comment 121"""""
+"""Test name 122","Test host 122""","Test ""username 122","Test ""password"" 122","Test """"comment 122"""""
+"""Test name 123","Test host 123""","Test ""username 123","Test ""password"" 123","Test """"comment 123"""""
+"""Test name 124","Test host 124""","Test ""username 124","Test ""password"" 124","Test """"comment 124"""""
+"""Test name 125","Test host 125""","Test ""username 125","Test ""password"" 125","Test """"comment 125"""""
+"""Test name 126","Test host 126""","Test ""username 126","Test ""password"" 126","Test """"comment 126"""""
+"""Test name 127","Test host 127""","Test ""username 127","Test ""password"" 127","Test """"comment 127"""""
+"""Test name 128","Test host 128""","Test ""username 128","Test ""password"" 128","Test """"comment 128"""""
+"""Test name 129","Test host 129""","Test ""username 129","Test ""password"" 129","Test """"comment 129"""""
+"""Test name 130","Test host 130""","Test ""username 130","Test ""password"" 130","Test """"comment 130"""""
+"""Test name 131","Test host 131""","Test ""username 131","Test ""password"" 131","Test """"comment 131"""""
+"""Test name 132","Test host 132""","Test ""username 132","Test ""password"" 132","Test """"comment 132"""""
+"""Test name 133","Test host 133""","Test ""username 133","Test ""password"" 133","Test """"comment 133"""""
+"""Test name 134","Test host 134""","Test ""username 134","Test ""password"" 134","Test """"comment 134"""""
+"""Test name 135","Test host 135""","Test ""username 135","Test ""password"" 135","Test """"comment 135"""""
+"""Test name 136","Test host 136""","Test ""username 136","Test ""password"" 136","Test """"comment 136"""""
+"""Test name 137","Test host 137""","Test ""username 137","Test ""password"" 137","Test """"comment 137"""""
+"""Test name 138","Test host 138""","Test ""username 138","Test ""password"" 138","Test """"comment 138"""""
+"""Test name 139","Test host 139""","Test ""username 139","Test ""password"" 139","Test """"comment 139"""""
+"""Test name 140","Test host 140""","Test ""username 140","Test ""password"" 140","Test """"comment 140"""""
+"""Test name 141","Test host 141""","Test ""username 141","Test ""password"" 141","Test """"comment 141"""""
+"""Test name 142","Test host 142""","Test ""username 142","Test ""password"" 142","Test """"comment 142"""""
+"""Test name 143","Test host 143""","Test ""username 143","Test ""password"" 143","Test """"comment 143"""""
+"""Test name 144","Test host 144""","Test ""username 144","Test ""password"" 144","Test """"comment 144"""""
+"""Test name 145","Test host 145""","Test ""username 145","Test ""password"" 145","Test """"comment 145"""""
+"""Test name 146","Test host 146""","Test ""username 146","Test ""password"" 146","Test """"comment 146"""""
+"""Test name 147","Test host 147""","Test ""username 147","Test ""password"" 147","Test """"comment 147"""""
+"""Test name 148","Test host 148""","Test ""username 148","Test ""password"" 148","Test """"comment 148"""""
+"""Test name 149","Test host 149""","Test ""username 149","Test ""password"" 149","Test """"comment 149"""""
+"""Test name 150","Test host 150""","Test ""username 150","Test ""password"" 150","Test """"comment 150"""""
+"""Test name 151","Test host 151""","Test ""username 151","Test ""password"" 151","Test """"comment 151"""""
+"""Test name 152","Test host 152""","Test ""username 152","Test ""password"" 152","Test """"comment 152"""""
+"""Test name 153","Test host 153""","Test ""username 153","Test ""password"" 153","Test """"comment 153"""""
+"""Test name 154","Test host 154""","Test ""username 154","Test ""password"" 154","Test """"comment 154"""""
+"""Test name 155","Test host 155""","Test ""username 155","Test ""password"" 155","Test """"comment 155"""""
+"""Test name 156","Test host 156""","Test ""username 156","Test ""password"" 156","Test """"comment 156"""""
+"""Test name 157","Test host 157""","Test ""username 157","Test ""password"" 157","Test """"comment 157"""""
+"""Test name 158","Test host 158""","Test ""username 158","Test ""password"" 158","Test """"comment 158"""""
+"""Test name 159","Test host 159""","Test ""username 159","Test ""password"" 159","Test """"comment 159"""""
+"""Test name 160","Test host 160""","Test ""username 160","Test ""password"" 160","Test """"comment 160"""""
+"""Test name 161","Test host 161""","Test ""username 161","Test ""password"" 161","Test """"comment 161"""""
+"""Test name 162","Test host 162""","Test ""username 162","Test ""password"" 162","Test """"comment 162"""""
+"""Test name 163","Test host 163""","Test ""username 163","Test ""password"" 163","Test """"comment 163"""""
+"""Test name 164","Test host 164""","Test ""username 164","Test ""password"" 164","Test """"comment 164"""""
+"""Test name 165","Test host 165""","Test ""username 165","Test ""password"" 165","Test """"comment 165"""""
+"""Test name 166","Test host 166""","Test ""username 166","Test ""password"" 166","Test """"comment 166"""""
+"""Test name 167","Test host 167""","Test ""username 167","Test ""password"" 167","Test """"comment 167"""""
+"""Test name 168","Test host 168""","Test ""username 168","Test ""password"" 168","Test """"comment 168"""""
+"""Test name 169","Test host 169""","Test ""username 169","Test ""password"" 169","Test """"comment 169"""""
+"""Test name 170","Test host 170""","Test ""username 170","Test ""password"" 170","Test """"comment 170"""""
+"""Test name 171","Test host 171""","Test ""username 171","Test ""password"" 171","Test """"comment 171"""""
+"""Test name 172","Test host 172""","Test ""username 172","Test ""password"" 172","Test """"comment 172"""""
+"""Test name 173","Test host 173""","Test ""username 173","Test ""password"" 173","Test """"comment 173"""""
+"""Test name 174","Test host 174""","Test ""username 174","Test ""password"" 174","Test """"comment 174"""""
+"""Test name 175","Test host 175""","Test ""username 175","Test ""password"" 175","Test """"comment 175"""""
+"""Test name 176","Test host 176""","Test ""username 176","Test ""password"" 176","Test """"comment 176"""""
+"""Test name 177","Test host 177""","Test ""username 177","Test ""password"" 177","Test """"comment 177"""""
+"""Test name 178","Test host 178""","Test ""username 178","Test ""password"" 178","Test """"comment 178"""""
+"""Test name 179","Test host 179""","Test ""username 179","Test ""password"" 179","Test """"comment 179"""""
+"""Test name 180","Test host 180""","Test ""username 180","Test ""password"" 180","Test """"comment 180"""""
+"""Test name 181","Test host 181""","Test ""username 181","Test ""password"" 181","Test """"comment 181"""""
+"""Test name 182","Test host 182""","Test ""username 182","Test ""password"" 182","Test """"comment 182"""""
+"""Test name 183","Test host 183""","Test ""username 183","Test ""password"" 183","Test """"comment 183"""""
+"""Test name 184","Test host 184""","Test ""username 184","Test ""password"" 184","Test """"comment 184"""""
+"""Test name 185","Test host 185""","Test ""username 185","Test ""password"" 185","Test """"comment 185"""""
+"""Test name 186","Test host 186""","Test ""username 186","Test ""password"" 186","Test """"comment 186"""""
+"""Test name 187","Test host 187""","Test ""username 187","Test ""password"" 187","Test """"comment 187"""""
+"""Test name 188","Test host 188""","Test ""username 188","Test ""password"" 188","Test """"comment 188"""""
+"""Test name 189","Test host 189""","Test ""username 189","Test ""password"" 189","Test """"comment 189"""""
+"""Test name 190","Test host 190""","Test ""username 190","Test ""password"" 190","Test """"comment 190"""""
+"""Test name 191","Test host 191""","Test ""username 191","Test ""password"" 191","Test """"comment 191"""""
+"""Test name 192","Test host 192""","Test ""username 192","Test ""password"" 192","Test """"comment 192"""""
+"""Test name 193","Test host 193""","Test ""username 193","Test ""password"" 193","Test """"comment 193"""""
+"""Test name 194","Test host 194""","Test ""username 194","Test ""password"" 194","Test """"comment 194"""""
+"""Test name 195","Test host 195""","Test ""username 195","Test ""password"" 195","Test """"comment 195"""""
+"""Test name 196","Test host 196""","Test ""username 196","Test ""password"" 196","Test """"comment 196"""""
+"""Test name 197","Test host 197""","Test ""username 197","Test ""password"" 197","Test """"comment 197"""""
+"""Test name 198","Test host 198""","Test ""username 198","Test ""password"" 198","Test """"comment 198"""""
+"""Test name 199","Test host 199""","Test ""username 199","Test ""password"" 199","Test """"comment 199"""""
diff -ruN yapet-0.4.bak/tests/test7.csv yapet-0.4/tests/test7.csv
--- yapet-0.4.bak/tests/test7.csv	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/test7.csv	2009-07-18 22:28:49.572663523 +0200
@@ -0,0 +1,200 @@
+",Test name 0","Test, host 0","Test username, 0","Test password 0","Test comment 0,"
+",Test name 1","Test, host 1","Test username, 1","Test password 1","Test comment 1,"
+",Test name 2","Test, host 2","Test username, 2","Test password 2","Test comment 2,"
+",Test name 3","Test, host 3","Test username, 3","Test password 3","Test comment 3,"
+",Test name 4","Test, host 4","Test username, 4","Test password 4","Test comment 4,"
+",Test name 5","Test, host 5","Test username, 5","Test password 5","Test comment 5,"
+",Test name 6","Test, host 6","Test username, 6","Test password 6","Test comment 6,"
+",Test name 7","Test, host 7","Test username, 7","Test password 7","Test comment 7,"
+",Test name 8","Test, host 8","Test username, 8","Test password 8","Test comment 8,"
+",Test name 9","Test, host 9","Test username, 9","Test password 9","Test comment 9,"
+",Test name 10","Test, host 10","Test username, 10","Test password 10","Test comment 10,"
+",Test name 11","Test, host 11","Test username, 11","Test password 11","Test comment 11,"
+",Test name 12","Test, host 12","Test username, 12","Test password 12","Test comment 12,"
+",Test name 13","Test, host 13","Test username, 13","Test password 13","Test comment 13,"
+",Test name 14","Test, host 14","Test username, 14","Test password 14","Test comment 14,"
+",Test name 15","Test, host 15","Test username, 15","Test password 15","Test comment 15,"
+",Test name 16","Test, host 16","Test username, 16","Test password 16","Test comment 16,"
+",Test name 17","Test, host 17","Test username, 17","Test password 17","Test comment 17,"
+",Test name 18","Test, host 18","Test username, 18","Test password 18","Test comment 18,"
+",Test name 19","Test, host 19","Test username, 19","Test password 19","Test comment 19,"
+",Test name 20","Test, host 20","Test username, 20","Test password 20","Test comment 20,"
+",Test name 21","Test, host 21","Test username, 21","Test password 21","Test comment 21,"
+",Test name 22","Test, host 22","Test username, 22","Test password 22","Test comment 22,"
+",Test name 23","Test, host 23","Test username, 23","Test password 23","Test comment 23,"
+",Test name 24","Test, host 24","Test username, 24","Test password 24","Test comment 24,"
+",Test name 25","Test, host 25","Test username, 25","Test password 25","Test comment 25,"
+",Test name 26","Test, host 26","Test username, 26","Test password 26","Test comment 26,"
+",Test name 27","Test, host 27","Test username, 27","Test password 27","Test comment 27,"
+",Test name 28","Test, host 28","Test username, 28","Test password 28","Test comment 28,"
+",Test name 29","Test, host 29","Test username, 29","Test password 29","Test comment 29,"
+",Test name 30","Test, host 30","Test username, 30","Test password 30","Test comment 30,"
+",Test name 31","Test, host 31","Test username, 31","Test password 31","Test comment 31,"
+",Test name 32","Test, host 32","Test username, 32","Test password 32","Test comment 32,"
+",Test name 33","Test, host 33","Test username, 33","Test password 33","Test comment 33,"
+",Test name 34","Test, host 34","Test username, 34","Test password 34","Test comment 34,"
+",Test name 35","Test, host 35","Test username, 35","Test password 35","Test comment 35,"
+",Test name 36","Test, host 36","Test username, 36","Test password 36","Test comment 36,"
+",Test name 37","Test, host 37","Test username, 37","Test password 37","Test comment 37,"
+",Test name 38","Test, host 38","Test username, 38","Test password 38","Test comment 38,"
+",Test name 39","Test, host 39","Test username, 39","Test password 39","Test comment 39,"
+",Test name 40","Test, host 40","Test username, 40","Test password 40","Test comment 40,"
+",Test name 41","Test, host 41","Test username, 41","Test password 41","Test comment 41,"
+",Test name 42","Test, host 42","Test username, 42","Test password 42","Test comment 42,"
+",Test name 43","Test, host 43","Test username, 43","Test password 43","Test comment 43,"
+",Test name 44","Test, host 44","Test username, 44","Test password 44","Test comment 44,"
+",Test name 45","Test, host 45","Test username, 45","Test password 45","Test comment 45,"
+",Test name 46","Test, host 46","Test username, 46","Test password 46","Test comment 46,"
+",Test name 47","Test, host 47","Test username, 47","Test password 47","Test comment 47,"
+",Test name 48","Test, host 48","Test username, 48","Test password 48","Test comment 48,"
+",Test name 49","Test, host 49","Test username, 49","Test password 49","Test comment 49,"
+",Test name 50","Test, host 50","Test username, 50","Test password 50","Test comment 50,"
+",Test name 51","Test, host 51","Test username, 51","Test password 51","Test comment 51,"
+",Test name 52","Test, host 52","Test username, 52","Test password 52","Test comment 52,"
+",Test name 53","Test, host 53","Test username, 53","Test password 53","Test comment 53,"
+",Test name 54","Test, host 54","Test username, 54","Test password 54","Test comment 54,"
+",Test name 55","Test, host 55","Test username, 55","Test password 55","Test comment 55,"
+",Test name 56","Test, host 56","Test username, 56","Test password 56","Test comment 56,"
+",Test name 57","Test, host 57","Test username, 57","Test password 57","Test comment 57,"
+",Test name 58","Test, host 58","Test username, 58","Test password 58","Test comment 58,"
+",Test name 59","Test, host 59","Test username, 59","Test password 59","Test comment 59,"
+",Test name 60","Test, host 60","Test username, 60","Test password 60","Test comment 60,"
+",Test name 61","Test, host 61","Test username, 61","Test password 61","Test comment 61,"
+",Test name 62","Test, host 62","Test username, 62","Test password 62","Test comment 62,"
+",Test name 63","Test, host 63","Test username, 63","Test password 63","Test comment 63,"
+",Test name 64","Test, host 64","Test username, 64","Test password 64","Test comment 64,"
+",Test name 65","Test, host 65","Test username, 65","Test password 65","Test comment 65,"
+",Test name 66","Test, host 66","Test username, 66","Test password 66","Test comment 66,"
+",Test name 67","Test, host 67","Test username, 67","Test password 67","Test comment 67,"
+",Test name 68","Test, host 68","Test username, 68","Test password 68","Test comment 68,"
+",Test name 69","Test, host 69","Test username, 69","Test password 69","Test comment 69,"
+",Test name 70","Test, host 70","Test username, 70","Test password 70","Test comment 70,"
+",Test name 71","Test, host 71","Test username, 71","Test password 71","Test comment 71,"
+",Test name 72","Test, host 72","Test username, 72","Test password 72","Test comment 72,"
+",Test name 73","Test, host 73","Test username, 73","Test password 73","Test comment 73,"
+",Test name 74","Test, host 74","Test username, 74","Test password 74","Test comment 74,"
+",Test name 75","Test, host 75","Test username, 75","Test password 75","Test comment 75,"
+",Test name 76","Test, host 76","Test username, 76","Test password 76","Test comment 76,"
+",Test name 77","Test, host 77","Test username, 77","Test password 77","Test comment 77,"
+",Test name 78","Test, host 78","Test username, 78","Test password 78","Test comment 78,"
+",Test name 79","Test, host 79","Test username, 79","Test password 79","Test comment 79,"
+",Test name 80","Test, host 80","Test username, 80","Test password 80","Test comment 80,"
+",Test name 81","Test, host 81","Test username, 81","Test password 81","Test comment 81,"
+",Test name 82","Test, host 82","Test username, 82","Test password 82","Test comment 82,"
+",Test name 83","Test, host 83","Test username, 83","Test password 83","Test comment 83,"
+",Test name 84","Test, host 84","Test username, 84","Test password 84","Test comment 84,"
+",Test name 85","Test, host 85","Test username, 85","Test password 85","Test comment 85,"
+",Test name 86","Test, host 86","Test username, 86","Test password 86","Test comment 86,"
+",Test name 87","Test, host 87","Test username, 87","Test password 87","Test comment 87,"
+",Test name 88","Test, host 88","Test username, 88","Test password 88","Test comment 88,"
+",Test name 89","Test, host 89","Test username, 89","Test password 89","Test comment 89,"
+",Test name 90","Test, host 90","Test username, 90","Test password 90","Test comment 90,"
+",Test name 91","Test, host 91","Test username, 91","Test password 91","Test comment 91,"
+",Test name 92","Test, host 92","Test username, 92","Test password 92","Test comment 92,"
+",Test name 93","Test, host 93","Test username, 93","Test password 93","Test comment 93,"
+",Test name 94","Test, host 94","Test username, 94","Test password 94","Test comment 94,"
+",Test name 95","Test, host 95","Test username, 95","Test password 95","Test comment 95,"
+",Test name 96","Test, host 96","Test username, 96","Test password 96","Test comment 96,"
+",Test name 97","Test, host 97","Test username, 97","Test password 97","Test comment 97,"
+",Test name 98","Test, host 98","Test username, 98","Test password 98","Test comment 98,"
+",Test name 99","Test, host 99","Test username, 99","Test password 99","Test comment 99,"
+",Test name 100","Test, host 100","Test username, 100","Test password 100","Test comment 100,"
+",Test name 101","Test, host 101","Test username, 101","Test password 101","Test comment 101,"
+",Test name 102","Test, host 102","Test username, 102","Test password 102","Test comment 102,"
+",Test name 103","Test, host 103","Test username, 103","Test password 103","Test comment 103,"
+",Test name 104","Test, host 104","Test username, 104","Test password 104","Test comment 104,"
+",Test name 105","Test, host 105","Test username, 105","Test password 105","Test comment 105,"
+",Test name 106","Test, host 106","Test username, 106","Test password 106","Test comment 106,"
+",Test name 107","Test, host 107","Test username, 107","Test password 107","Test comment 107,"
+",Test name 108","Test, host 108","Test username, 108","Test password 108","Test comment 108,"
+",Test name 109","Test, host 109","Test username, 109","Test password 109","Test comment 109,"
+",Test name 110","Test, host 110","Test username, 110","Test password 110","Test comment 110,"
+",Test name 111","Test, host 111","Test username, 111","Test password 111","Test comment 111,"
+",Test name 112","Test, host 112","Test username, 112","Test password 112","Test comment 112,"
+",Test name 113","Test, host 113","Test username, 113","Test password 113","Test comment 113,"
+",Test name 114","Test, host 114","Test username, 114","Test password 114","Test comment 114,"
+",Test name 115","Test, host 115","Test username, 115","Test password 115","Test comment 115,"
+",Test name 116","Test, host 116","Test username, 116","Test password 116","Test comment 116,"
+",Test name 117","Test, host 117","Test username, 117","Test password 117","Test comment 117,"
+",Test name 118","Test, host 118","Test username, 118","Test password 118","Test comment 118,"
+",Test name 119","Test, host 119","Test username, 119","Test password 119","Test comment 119,"
+",Test name 120","Test, host 120","Test username, 120","Test password 120","Test comment 120,"
+",Test name 121","Test, host 121","Test username, 121","Test password 121","Test comment 121,"
+",Test name 122","Test, host 122","Test username, 122","Test password 122","Test comment 122,"
+",Test name 123","Test, host 123","Test username, 123","Test password 123","Test comment 123,"
+",Test name 124","Test, host 124","Test username, 124","Test password 124","Test comment 124,"
+",Test name 125","Test, host 125","Test username, 125","Test password 125","Test comment 125,"
+",Test name 126","Test, host 126","Test username, 126","Test password 126","Test comment 126,"
+",Test name 127","Test, host 127","Test username, 127","Test password 127","Test comment 127,"
+",Test name 128","Test, host 128","Test username, 128","Test password 128","Test comment 128,"
+",Test name 129","Test, host 129","Test username, 129","Test password 129","Test comment 129,"
+",Test name 130","Test, host 130","Test username, 130","Test password 130","Test comment 130,"
+",Test name 131","Test, host 131","Test username, 131","Test password 131","Test comment 131,"
+",Test name 132","Test, host 132","Test username, 132","Test password 132","Test comment 132,"
+",Test name 133","Test, host 133","Test username, 133","Test password 133","Test comment 133,"
+",Test name 134","Test, host 134","Test username, 134","Test password 134","Test comment 134,"
+",Test name 135","Test, host 135","Test username, 135","Test password 135","Test comment 135,"
+",Test name 136","Test, host 136","Test username, 136","Test password 136","Test comment 136,"
+",Test name 137","Test, host 137","Test username, 137","Test password 137","Test comment 137,"
+",Test name 138","Test, host 138","Test username, 138","Test password 138","Test comment 138,"
+",Test name 139","Test, host 139","Test username, 139","Test password 139","Test comment 139,"
+",Test name 140","Test, host 140","Test username, 140","Test password 140","Test comment 140,"
+",Test name 141","Test, host 141","Test username, 141","Test password 141","Test comment 141,"
+",Test name 142","Test, host 142","Test username, 142","Test password 142","Test comment 142,"
+",Test name 143","Test, host 143","Test username, 143","Test password 143","Test comment 143,"
+",Test name 144","Test, host 144","Test username, 144","Test password 144","Test comment 144,"
+",Test name 145","Test, host 145","Test username, 145","Test password 145","Test comment 145,"
+",Test name 146","Test, host 146","Test username, 146","Test password 146","Test comment 146,"
+",Test name 147","Test, host 147","Test username, 147","Test password 147","Test comment 147,"
+",Test name 148","Test, host 148","Test username, 148","Test password 148","Test comment 148,"
+",Test name 149","Test, host 149","Test username, 149","Test password 149","Test comment 149,"
+",Test name 150","Test, host 150","Test username, 150","Test password 150","Test comment 150,"
+",Test name 151","Test, host 151","Test username, 151","Test password 151","Test comment 151,"
+",Test name 152","Test, host 152","Test username, 152","Test password 152","Test comment 152,"
+",Test name 153","Test, host 153","Test username, 153","Test password 153","Test comment 153,"
+",Test name 154","Test, host 154","Test username, 154","Test password 154","Test comment 154,"
+",Test name 155","Test, host 155","Test username, 155","Test password 155","Test comment 155,"
+",Test name 156","Test, host 156","Test username, 156","Test password 156","Test comment 156,"
+",Test name 157","Test, host 157","Test username, 157","Test password 157","Test comment 157,"
+",Test name 158","Test, host 158","Test username, 158","Test password 158","Test comment 158,"
+",Test name 159","Test, host 159","Test username, 159","Test password 159","Test comment 159,"
+",Test name 160","Test, host 160","Test username, 160","Test password 160","Test comment 160,"
+",Test name 161","Test, host 161","Test username, 161","Test password 161","Test comment 161,"
+",Test name 162","Test, host 162","Test username, 162","Test password 162","Test comment 162,"
+",Test name 163","Test, host 163","Test username, 163","Test password 163","Test comment 163,"
+",Test name 164","Test, host 164","Test username, 164","Test password 164","Test comment 164,"
+",Test name 165","Test, host 165","Test username, 165","Test password 165","Test comment 165,"
+",Test name 166","Test, host 166","Test username, 166","Test password 166","Test comment 166,"
+",Test name 167","Test, host 167","Test username, 167","Test password 167","Test comment 167,"
+",Test name 168","Test, host 168","Test username, 168","Test password 168","Test comment 168,"
+",Test name 169","Test, host 169","Test username, 169","Test password 169","Test comment 169,"
+",Test name 170","Test, host 170","Test username, 170","Test password 170","Test comment 170,"
+",Test name 171","Test, host 171","Test username, 171","Test password 171","Test comment 171,"
+",Test name 172","Test, host 172","Test username, 172","Test password 172","Test comment 172,"
+",Test name 173","Test, host 173","Test username, 173","Test password 173","Test comment 173,"
+",Test name 174","Test, host 174","Test username, 174","Test password 174","Test comment 174,"
+",Test name 175","Test, host 175","Test username, 175","Test password 175","Test comment 175,"
+",Test name 176","Test, host 176","Test username, 176","Test password 176","Test comment 176,"
+",Test name 177","Test, host 177","Test username, 177","Test password 177","Test comment 177,"
+",Test name 178","Test, host 178","Test username, 178","Test password 178","Test comment 178,"
+",Test name 179","Test, host 179","Test username, 179","Test password 179","Test comment 179,"
+",Test name 180","Test, host 180","Test username, 180","Test password 180","Test comment 180,"
+",Test name 181","Test, host 181","Test username, 181","Test password 181","Test comment 181,"
+",Test name 182","Test, host 182","Test username, 182","Test password 182","Test comment 182,"
+",Test name 183","Test, host 183","Test username, 183","Test password 183","Test comment 183,"
+",Test name 184","Test, host 184","Test username, 184","Test password 184","Test comment 184,"
+",Test name 185","Test, host 185","Test username, 185","Test password 185","Test comment 185,"
+",Test name 186","Test, host 186","Test username, 186","Test password 186","Test comment 186,"
+",Test name 187","Test, host 187","Test username, 187","Test password 187","Test comment 187,"
+",Test name 188","Test, host 188","Test username, 188","Test password 188","Test comment 188,"
+",Test name 189","Test, host 189","Test username, 189","Test password 189","Test comment 189,"
+",Test name 190","Test, host 190","Test username, 190","Test password 190","Test comment 190,"
+",Test name 191","Test, host 191","Test username, 191","Test password 191","Test comment 191,"
+",Test name 192","Test, host 192","Test username, 192","Test password 192","Test comment 192,"
+",Test name 193","Test, host 193","Test username, 193","Test password 193","Test comment 193,"
+",Test name 194","Test, host 194","Test username, 194","Test password 194","Test comment 194,"
+",Test name 195","Test, host 195","Test username, 195","Test password 195","Test comment 195,"
+",Test name 196","Test, host 196","Test username, 196","Test password 196","Test comment 196,"
+",Test name 197","Test, host 197","Test username, 197","Test password 197","Test comment 197,"
+",Test name 198","Test, host 198","Test username, 198","Test password 198","Test comment 198,"
+",Test name 199","Test, host 199","Test username, 199","Test password 199","Test comment 199,"
diff -ruN yapet-0.4.bak/tests/test8.csv yapet-0.4/tests/test8.csv
--- yapet-0.4.bak/tests/test8.csv	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/test8.csv	2009-07-18 22:40:51.852643216 +0200
@@ -0,0 +1,4 @@
+name1,"host1,username1,password1,comment1
+name2,host2,username2,"password2",comment2
+name3,host3,username3,password3,comment3"
+name4,host4,username4,password4,comment4
diff -ruN yapet-0.4.bak/tests/test9.csv yapet-0.4/tests/test9.csv
--- yapet-0.4.bak/tests/test9.csv	1970-01-01 01:00:00.000000000 +0100
+++ yapet-0.4/tests/test9.csv	2009-07-18 22:49:42.868653363 +0200
@@ -0,0 +1,6 @@
+name0,host0,username0,password0,comment0
+name1,"",",",password1,comment1
+name2,host2,username2,password2,""
+"name3",host3,username3,password3,comment3
+",,,,,",host4,username4,password4,comment4
+",",",",",",",",","
diff -ruN yapet-0.4.bak/tests/tests.h yapet-0.4/tests/tests.h
--- yapet-0.4.bak/tests/tests.h	2009-07-06 23:43:05.000000000 +0200
+++ yapet-0.4/tests/tests.h	2009-07-18 22:09:29.520663447 +0200
@@ -12,13 +12,31 @@
 #include <key.h>
 #include <crypt.h>
 
-#define ROUNDS 5000
+#ifndef ROUNDS
+# define ROUNDS 5000
+#endif
+
 #define FN "encryptiontest.gps"
-#define NAME "Test name %d"
-#define HOST "Test host %d"
-#define UNAME "Test username %d"
-#define PW "Test password %d"
-#define COMMENT "Test comment %d"
+
+#ifndef NAME
+# define NAME "Test name %d"
+#endif
+
+#ifndef HOST
+# define HOST "Test host %d"
+#endif
+
+#ifndef UNAME
+# define UNAME "Test username %d"
+#endif
+
+#ifndef PW
+# define PW "Test password %d"
+#endif
+
+#ifndef COMMENT
+# define COMMENT "Test comment %d"
+#endif
 
 
 inline
